import { CdkDragDrop } from '@angular/cdk/drag-drop';
import { EventEmitter, OnChanges, OnDestroy, OnInit, SimpleChanges } from '@angular/core';
import { FormGroup } from '@angular/forms';
import { TAttributeListRole } from './attributes-list/attributes-list.types';
import { IAttributeItem } from '../shared/interfaces/attribute-item.interface';
import { ILockedAttribute } from '../shared/interfaces/locked-attributes.interface';
import { InboxState } from '../inbox/state/inbox.state';
import * as i0 from "@angular/core";
/**
 * Attributes settings are responsible for providing content to the selected attributes within the data items list and data item information.
 *
 * ```html
 * <talenra-attributes-settings
 *   [attributesSettingsList]="attributesSettingsList"
 *   [maxAttributesShown]="maxAttributesShown"
 *   [selectedMainAttributes]="selectedMainAttributes"
 *   [selectedDetailAttributes]="selectedDetailAttributes"
 *   [isExpanded]="isExpanded"
 *   (isExpandedChange)="expandedChangeHandler($event)"
 *   (selectedMainAttributesEmitter)="selectedMainAttributesEmitterHandler($event)"
 *   (selectedDetailAttributesEmitter)="selectedDetailAttributesEmitterHandler($event)"
 *   (selectedAllAttributesEmitter)="selectedAllAttributesEmitterHandler($event)"
 * ></talenra-attributes-settings>
 * ```
 */
export declare class AttributesSettingsComponent implements OnInit, OnChanges, OnDestroy {
    /**
     * The used attributes are listed to display them later in the attributes settings UI.
     */
    attributesSettingsList?: IAttributeItem[];
    /**
     * The maximum Attributes, which are to be shown in the data-item-list-items.
     * Further they are divided in the ui.
     * Marks the border for which values are saved to attributes and attributes-detail in attributes-settings-service.
     * Default value is 12, like chosen in the requirements.
     */
    maxAttributesShown: number;
    /**
     * The maximum Attributes, which are to be shown in the data-item-list-items mutated by the user.
     */
    numberMainAttributesChosenByUser: number;
    /**
     * The boolean value is used to expand the attributes settings UI.
     */
    isExpanded: boolean;
    /**
     * Sets the selected main attributes.
     */
    selectedMainAttributes: IAttributeItem[];
    /**
     * Sets the selected detail attributes.
     */
    selectedDetailAttributes: IAttributeItem[];
    /**
     * List of attributes key which are used to lock the attributes in the attribute settings.
     * Gets updated by the used attributes in the filter toolbar.
     */
    lockedAttributes: ILockedAttribute[];
    /**
     * Emits the main selected attributes.
     */
    selectedMainAttributesEmitter: EventEmitter<IAttributeItem[]>;
    /**
     * Emits the detail selected attributes.
     */
    selectedDetailAttributesEmitter: EventEmitter<IAttributeItem[]>;
    /**
     * Emits the all selected attributes.
     */
    selectedAllAttributesEmitter: EventEmitter<IAttributeItem[]>;
    /**
     * The number value that is chosen by the user to show the main attributes.
     */
    numberMainAttributesChosenByUserEmitter: EventEmitter<number>;
    /**
     * The main attributes.
     */
    mainAttributes: IAttributeItem[];
    /**
     * The detail attributes.
     */
    detailAttributes: IAttributeItem[];
    /**
     * The detail attributes.
     */
    detailAttributesSearch: IAttributeItem[];
    /**
     * Boolean to know if all checkboxes are checked.
     */
    allAttributesSettingsChecked: FormGroup;
    /**
     * List style for the checkbox behavior and UI.
     */
    indeterminateAllAttributes: boolean;
    /**
     * List of all marked attributes labels
     */
    markedAttributes: string[];
    /**
     * The inbox service.
     */
    inboxState: InboxState;
    /**
     * Boolean to set if label is shown.
     */
    showAttributeLabelsDataItemsList: boolean | undefined;
    /**
     * The form-group which defines the overall form consisting most of the time
     * of multiple inputs, gets passed into the component.
     * Get Value HTML:
     *     {{searchField.get(searchFieldFcn)!.value}}
     */
    protected searchForm: FormGroup;
    /**
     * Semaphore to stop accessing checkbox value a second time.
     * @internal
     */
    private checkboxSemaphore;
    /**
     * Semaphore to stop multiple change save.
     * @internal
     */
    private multipleChangeSemaphore;
    /**
     * The subscriptions of the component.
     *  @internal
     */
    private subscriptions;
    /**
     * Returns whether list-style "narrow" (a more compact layout) is preferred. The compact layout is used for extensive
     * numbers of attributes.
     *
     * @internal
     */
    protected get preferNarrowList(): boolean;
    /** @internal */
    private get classNames();
    /**
     * The initialization of the component.
     * @internal
     */
    ngOnInit(): void;
    /**
     * Detects changes in the component.
     * @internal
     **/
    ngOnChanges(changes: SimpleChanges): void;
    /**
     * Unsubscribes from all subscriptions.
     * @internal
     */
    ngOnDestroy(): void;
    /**
     * Auxiliary method to create a list for the checked items.
     * @param list The list that contains the attributes.
     * @internal
     */
    createList(list: IAttributeItem[]): IAttributeItem[];
    /**
     * Called if attributes are changed and have to be emitted.
     */
    onAttributesSettingsChanges(): void;
    /**
     * Handler to mark attributes.
     * @param {IAttributeItem} item Clicked attribute.
     */
    handleMarkedAttribute(item: IAttributeItem): void;
    /**
     * Auxiliary method to mark chosen attributes.
     * @param {string} id Attributes name of the marked attributes.
     * @internal
     */
    markAttribute(id: string): void;
    /**
     * Auxiliary method to unmark chosen attributes.
     * @param {string} id Attributes name of the unmarked attributes.
     * @internal
     */
    unmarkAttribute(id: string): void;
    /**
     * Auxiliary method to get the chosen attribute.
     * @param {string} id Attribute name of the chosen attribute.
     * @internal
     */
    getMarkedAttribute(id: string): string;
    /**
     * To change the array place of dragged item.
     * @param event The dragged item.
     * @param list The list to move the item to. True for main list, false for detail list.
     * @internal
     */
    onDrop(list: TAttributeListRole, event: CdkDragDrop<IAttributeItem[]>): void;
    /**
     * Update Attributes of the view to the current state.
     */
    updateAttributes(): void;
    /**
     * Method to get if the search field is active.
     */
    isSearchActive(): boolean;
    /**
     * Method to reset the attributes.
     */
    resetAttributes(): void;
    /**
     * Method to set the checkbox value of all attributes checkbox.
     * @param value The value of the checkbox.
     */
    allAttributesSettingsCheckedChange(value: boolean): void;
    /**
     * Method to set the toggle to show or not show labels in data items.
     * @param $event The event that is triggered by the click.
     */
    changeShowAttributeLabelsDataItemsList($event: boolean): void;
    /**
     * Checks if the filter is active.
     * @param attributeLabel The label of the filter.
     */
    isFilterActive(attributeLabel: string): boolean;
    /**
     * Checks if the sort is active.
     * @param attributeLabel The label of the filter.
     */
    isSortActive(attributeLabel: string): boolean;
    /**
     * Method to move the attribute to the other part of the list.
     * @param list The list to move the item to ('primary' or 'secondary')
     * @param index The index of the item.
     * @param event The event that is triggered by the click.
     */
    protected moveToOtherList(list: TAttributeListRole, index: number, event?: MouseEvent | undefined): void;
    /**
     * Decrease/increase the maximum attributes shown
     */
    protected updateAttributesMax(deviation: number): void;
    /**
     * The initialization of the component.
     * @private
     */
    private initializeComponent;
    /**
     * Method to order the selected attributes.
     */
    private orderAttributes;
    /**
     * Method to lock the attributes.
     */
    private lockAttributes;
    /**
     * Auxiliary method to check for locked attributes and disable the first element.
     * Furthermore, reset search of attributes detail list and call onAttributesSettingsChanges.
     * @private
     */
    private checkLockedAttributesDisableFirstElement;
    static ɵfac: i0.ɵɵFactoryDeclaration<AttributesSettingsComponent, never>;
    static ɵcmp: i0.ɵɵComponentDeclaration<AttributesSettingsComponent, "talenra-attributes-settings", never, { "attributesSettingsList": { "alias": "attributesSettingsList"; "required": false; }; "maxAttributesShown": { "alias": "maxAttributesShown"; "required": false; }; "numberMainAttributesChosenByUser": { "alias": "numberMainAttributesChosenByUser"; "required": false; }; "isExpanded": { "alias": "isExpanded"; "required": false; }; "selectedMainAttributes": { "alias": "selectedMainAttributes"; "required": false; }; "selectedDetailAttributes": { "alias": "selectedDetailAttributes"; "required": false; }; "lockedAttributes": { "alias": "lockedAttributes"; "required": false; }; }, { "selectedMainAttributesEmitter": "selectedMainAttributesEmitter"; "selectedDetailAttributesEmitter": "selectedDetailAttributesEmitter"; "selectedAllAttributesEmitter": "selectedAllAttributesEmitter"; "numberMainAttributesChosenByUserEmitter": "numberMainAttributesChosenByUserEmitter"; }, never, never, true, never>;
}
