import { EventEmitter, OnChanges, OnInit, SimpleChanges } from '@angular/core';
import { IQueryBuilderPossibleRule, IQueryBuilderQuery, IQueryBuilderValueOptions } from '@talenra/ngx-base/query-builder';
import { IAttributeItem } from '../shared/interfaces/attribute-item.interface';
import { ILockedAttribute } from '../shared/interfaces/locked-attributes.interface';
import { InboxState } from '../inbox/state/inbox.state';
import { KeyboardService } from '../inbox/services/keyboard.service';
import { FilterToolbarService } from '../filter-toolbar/filter-toolbar.service';
import { IInboxTabBarItem } from '../shared/interfaces/inbox-tab-bar-item.interface';
import { TConfigurationPanelBottomBarActions } from '../shared/types/configuration-panel.types';
import { IFilterAttribute } from '../shared/interfaces/filter-attribute.interface';
import { UpdatePresetsService } from '../inbox/services/update-presets.service';
import { FilterStateService } from '../simple-filter-selection/state/filter.state';
import { ChangedPresetValuesService } from '../inbox/services/changed-preset-values.service';
import { ISortAttributesInput } from '../shared/interfaces/sort-attributes-input.interface';
import { MainFacadeSetterService } from '../inbox/services/main-facade-setter.service';
import * as i0 from "@angular/core";
/**
 * Responsible for customizing the layout of the data item settings component.
 *
 * ```html
 * <talenra-inbox-configuration-panel
 *   *ngIf="!loading; else skeletonLoading"
 *   [attributesSettingsList]="attributeList"
 *   [maxAttributesShown]="maxAttributesShown"
 *   [selectedMainAttributes]="selectedMainAttributes"
 *   [selectedDetailAttributes]="selectedDetailAttributes"
 *   [(isExpanded)]="keyboardService.attributesSettingsExpanded"
 *   (selectedMainAttributesEmitter)="selectedMainAttributesEmitterHandler($event)"
 *   (selectedDetailAttributesEmitter)="selectedDetailAttributesEmitterHandler($event)"
 *   (selectedAllAttributesEmitter)="selectedAllAttributesEmitterHandler($event)"
 *   (buttonAction)="onButtonAction($event)"
 * ></talenra-inbox-configuration-panel>
 * ```
 */
export declare class InboxConfigurationPanelComponent implements OnInit, OnChanges {
    /**
     * The used attributes are listed to display them later in the attributes settings UI.
     */
    attributesSettingsList?: IAttributeItem[];
    /**
     * The maximum Attributes which are to be shown in the data-items-list-items.
     * Further they are divided in the ui.
     * Marks the border for which values are saved to attributes and attributes-detail in attributes-settings-service.
     * Default value is 12, like chosen in the requirements.
     */
    maxAttributesShown: number;
    /**
     * The maximum Attributes, which are to be shown in the data-items-list-items mutated by the user.
     */
    numberMainAttributesChosenByUser: number;
    /**
     * The boolean value is used to expand the attributes settings UI.
     */
    isExpanded: boolean;
    /**
     * Sets the selected main attributes.
     */
    selectedMainAttributes: IAttributeItem[];
    /**
     * Sets the selected detail attributes.
     */
    selectedDetailAttributes: IAttributeItem[];
    /**
     * The selected tab. Should contain the key of the tab.
     */
    selectedTab: import("@angular/core").ModelSignal<string>;
    /**
     * The query that is currently selected.
     */
    query: import("@angular/core").ModelSignal<IQueryBuilderQuery>;
    /**
     * The possible rules that can be selected.
     */
    possibleRules: import("@angular/core").InputSignal<IQueryBuilderPossibleRule[]>;
    /**
     * The values that can be selected in connection to each rule identifier.
     */
    possibleOptions: import("@angular/core").InputSignal<IQueryBuilderValueOptions[]>;
    /**
     * The extra tabs for the panel.
     */
    customTabs: import("@angular/core").InputSignal<IInboxTabBarItem[]>;
    /**
     * The filterSelection input is an array of strings that contains the selected filters.
     */
    filterSelections: import("@angular/core").ModelSignal<IFilterAttribute[]>;
    /**
     * The sortSelections input is an array of strings that contains the selected sorts.
     */
    sortSelections: import("@angular/core").ModelSignal<ISortAttributesInput[]>;
    /**
     * Emits the main selected attributes.
     */
    selectedMainAttributesEmitter: EventEmitter<IAttributeItem[]>;
    /**
     * Emits the detail selected attributes.
     */
    selectedDetailAttributesEmitter: EventEmitter<IAttributeItem[]>;
    /**
     * Emits the all selected attributes.
     */
    selectedAllAttributesEmitter: EventEmitter<IAttributeItem[]>;
    /**
     * The boolean value is used to expand the attributes settings UI.
     */
    isExpandedChange: EventEmitter<boolean>;
    /**
     * The number value that is chosen by the user to show the main attributes.
     */
    numberMainAttributesChosenByUserEmitter: EventEmitter<number>;
    /**
     * Emits actions.
     */
    buttonAction: import("@angular/core").OutputEmitterRef<TConfigurationPanelBottomBarActions>;
    /**
     * The selectedFilters output is an array of strings that contains the selected filters.
     */
    selectedFilters: import("@angular/core").OutputEmitterRef<IFilterAttribute[]>;
    /**
     * The selectedSorts output is an array that contains the selected sorts.
     */
    selectedSorts: import("@angular/core").OutputEmitterRef<ISortAttributesInput[]>;
    /**
     * List of attributes key which are used to lock the attributes in the attribute settings.
     * Gets updated by the used attributes in the filter toolbar.
     */
    lockedAttributes: ILockedAttribute[];
    /**
     * The tab bar items.
     */
    tabBarItems: IInboxTabBarItem[];
    /**
     * List of available attributes for the simple filter selection.
     */
    availableFilterSelectionAttributes: IAttributeItem[];
    /**
     * List of available attributes for the simple filter selection.
     */
    availableSortSelectionAttributes: IAttributeItem[];
    /**
     * The filter kind.
     * false = simple filter
     * true = expert filter
     */
    filterKind: boolean;
    /**
     * The used services and references.
     */
    filterToolbarService: FilterToolbarService;
    inboxState: InboxState;
    filterState: FilterStateService;
    keyboardService: KeyboardService;
    updatePresetsService: UpdatePresetsService;
    changedValuesService: ChangedPresetValuesService;
    /**
     * Injected set inbox configuration service.
     */
    mainFacadeSetterService: MainFacadeSetterService;
    /**
     * Destroy references to subscriptions.
     */
    private destroyRef;
    /**
     * Emits the selected main attributes.
     * @param selectedMainAttributes The selected main attributes.
     */
    selectedMainAttributesEmitterHandler(selectedMainAttributes: IAttributeItem[]): void;
    /**
     * Emits the selected detail attributes.
     * @param selectedDetailAttributes The selected detail attributes.
     */
    selectedDetailAttributesEmitterHandler(selectedDetailAttributes: IAttributeItem[]): void;
    /**
     * Emits the selected all attributes.
     * @param selectedAllAttributes All selected attributes.
     */
    selectedAllAttributesEmitterHandler(selectedAllAttributes: IAttributeItem[]): void;
    /**
     * Emits the expanded change.
     * @param $event The boolean value is used to expand the attributes settings UI.
     */
    expandedChangeHandler($event: boolean): void;
    /**
     * Emits the number main attributes chosen by user change.
     * @param $event The number value that is chosen by the user to show the main attributes.
     */
    numberMainAttributesChosenByUserHandler($event: number): void;
    /**
     * @internal
     */
    ngOnInit(): void;
    /**
     * Detects changes in the component.
     * @internal
     **/
    ngOnChanges(changes: SimpleChanges): void;
    /**
     * Change the selected tab.
     * @param tabKey The selected tab.
     */
    selectedTabChange(tabKey: string): void;
    /**
     * Change the filter kind.
     * @param kind The filter kind.
     */
    filterKindChange(kind: boolean): void;
    /**
     * Method to emit the close button and close the inbox detail view
     */
    onCloseClick(): void;
    /**
     * The action that is to be performed in for the items.
     * @param action The action clicked in the bottom bar.
     */
    onBottomBarAction(action: TConfigurationPanelBottomBarActions): void;
    /**
     * The action that is to be performed in for the items.
     * @param filterAttributes The selected filter attributes.
     */
    onSelectedFilters(filterAttributes: IFilterAttribute[]): void;
    /**
     * Handles the sort change.
     * @param sort
     */
    onSortChange(sort: ISortAttributesInput[]): void;
    /**
     * Switches to the expert filter and adds chosen simple filter elements to the expert filter query.
     * @protected
     */
    protected switchToExpertFilter(transferSimpleFilter?: boolean): void;
    /**
     * Switches from the expert filter to the simple filter.
     * Resets the simple filter to the view values.
     * @protected
     */
    protected switchToSimpleFilter(): void;
    /**
     * Method to reset the advanced filter.
     * @protected
     */
    protected resetExpertFilter(): void;
    protected onClickOutside(event: MouseEvent): void;
    /**
     * Initializes the component.
     * @protected
     */
    protected initializeComponent(): void;
    /**
     * Confirms the advanced filter.
     * @protected
     */
    protected confirmAdvancedFilter(): void;
    /**
     * Copies the query to clipboard.
     * @protected
     */
    protected onQueryDownload(): void;
    /**
     * Pastes the query.
     * @protected
     */
    protected onQueryUpload(): void;
    /**
     * Sets the all available attributes for the filter selection.
     * @param selectedAllAttributes The selected all attributes.
     * @private
     */
    private setAllFilterSelectionAttributes;
    /**
     * Generates the possible tab items and sets the to the tab bar items.
     * @private
     */
    private setTabItems;
    /**
     * Transfers the simple filter to the expert filter.
     * @private
     */
    private transferSimpleFilterToExpertFilter;
    /**
     * Set locked attributes from the filter selection.
     */
    private setLockedAttributesFilter;
    /**
     * Set locked attributes from the sort selection.
     */
    private setLockedAttributesSort;
    static ɵfac: i0.ɵɵFactoryDeclaration<InboxConfigurationPanelComponent, never>;
    static ɵcmp: i0.ɵɵComponentDeclaration<InboxConfigurationPanelComponent, "talenra-inbox-configuration-panel", never, { "attributesSettingsList": { "alias": "attributesSettingsList"; "required": false; }; "maxAttributesShown": { "alias": "maxAttributesShown"; "required": false; }; "numberMainAttributesChosenByUser": { "alias": "numberMainAttributesChosenByUser"; "required": false; }; "isExpanded": { "alias": "isExpanded"; "required": false; }; "selectedMainAttributes": { "alias": "selectedMainAttributes"; "required": false; }; "selectedDetailAttributes": { "alias": "selectedDetailAttributes"; "required": false; }; "selectedTab": { "alias": "selectedTab"; "required": false; "isSignal": true; }; "query": { "alias": "query"; "required": false; "isSignal": true; }; "possibleRules": { "alias": "possibleRules"; "required": false; "isSignal": true; }; "possibleOptions": { "alias": "possibleOptions"; "required": false; "isSignal": true; }; "customTabs": { "alias": "customTabs"; "required": false; "isSignal": true; }; "filterSelections": { "alias": "filterSelections"; "required": false; "isSignal": true; }; "sortSelections": { "alias": "sortSelections"; "required": false; "isSignal": true; }; }, { "selectedTab": "selectedTabChange"; "query": "queryChange"; "filterSelections": "filterSelectionsChange"; "sortSelections": "sortSelectionsChange"; "selectedMainAttributesEmitter": "selectedMainAttributesEmitter"; "selectedDetailAttributesEmitter": "selectedDetailAttributesEmitter"; "selectedAllAttributesEmitter": "selectedAllAttributesEmitter"; "isExpandedChange": "isExpandedChange"; "numberMainAttributesChosenByUserEmitter": "numberMainAttributesChosenByUserEmitter"; "buttonAction": "buttonAction"; "selectedFilters": "selectedFilters"; "selectedSorts": "selectedSorts"; }, never, ["*"], true, never>;
}
