import { AfterViewInit, EventEmitter, OnChanges, OnDestroy, OnInit, SimpleChanges } from '@angular/core';
import { FormGroup } from '@angular/forms';
import { DataItemsService } from './data-items.service';
import { CheckboxState } from '../../shared/types/checkbox.types';
import { IMarkedItemFormGroup } from '../../shared/interfaces/marked-item.interface';
import { IInteractedDataItems } from '../../shared/interfaces/interacted-data-items.interface';
import { IPairingAttributes } from '../../shared/interfaces/pairing-attributes.interface';
import { IAttributeItem } from '../../shared/interfaces/attribute-item.interface';
import { IDataItemId } from '../../shared/interfaces/data-item-id.interface';
import { DataItemsClass } from '../../shared/classes/dataItem.class';
import * as i0 from "@angular/core";
/**
 * One of the main components of the application. Responsible for ensuring that the transmitted data is properly structured to the user.
 *
 * ```html
 * <talenra-data-items-list
 *   [dataItemsChange]="filteredDataItems"
 *   [scrollToIndex]="keyboardService.scrollToIndex"
 *   [furtherActionsMenu]="furtherActionsMenu"
 *   (dataItemsInteractions)="onDataItemsInteractions($event)"
 *   (clickedDataItems)="selectedDataItem($event)"
 *   (scrollChange)="onScrollChange($event)"
 * ></talenra-data-items-list>
 * ```
 */
export declare class DataItemsListComponent implements OnInit, OnDestroy, OnChanges, AfterViewInit {
    /**
     * Input attribute for the data items list to be displayed in the UI.
     */
    dataItems: any[];
    /**
     * Input attribute for the selected data item to be displayed in the UI.
     */
    selectedDataItem: any;
    /**
     * Input attribute for the selected main attributes to be displayed in attributes settings and data items list.
     */
    selectedMainAttributes: IAttributeItem[];
    /**
     * pairing of attributes to be displayed in the UI.
     */
    pairingAttributes: IPairingAttributes[];
    /**
     * Input attribute to scroll to specific index
     */
    scrollToIndex: number;
    /**
     * The locked data items for the data item list.
     */
    lockedDataItems?: IDataItemId[];
    /**
     * Checkbox state of the toolbar checkbox.
     * The state changes all the checkboxes in the data items list.
     * Outline: No checkbox is checked.
     * Indeterminate: Does not change the state of the checkboxes.
     * Checked: All checkboxes are checked.
     */
    mainCheckboxState: CheckboxState;
    /**
     * Transfer the clicked data item from the data item list to the data item sidebar information.
     */
    clickedDataItem: EventEmitter<any>;
    /**
     * EventEmitter to send data items interactions.
     */
    dataItemsInteractions: EventEmitter<IInteractedDataItems>;
    /**
     * EventEmitter to send change in Scroll Position.
     */
    virtualScrollChange: EventEmitter<number>;
    /**
     * EventEmitter to send change number of marked data items.
     */
    numberMarkedDataItemsChange: EventEmitter<number>;
    /**
     * Emitter for the change in the checkbox state of the toolbar checkbox.
     */
    mainCheckboxStateChange: EventEmitter<CheckboxState>;
    /**
     * Class to interact with data-items-list-data.
     */
    dataItemsClass: DataItemsClass;
    /**
     * List of all marked data items names
     */
    markedDataItems: string[];
    /**
     * List of all locked data items inbox id's.
     */
    lockedDataItemsInboxId: string[];
    /**
     * List of all data items names which have been marked through click on the checkbox
     */
    markedDataItemsFormGroupCheckboxes: IMarkedItemFormGroup[];
    /**
     * The data items service.
     */
    dataItemsService: DataItemsService;
    /**
     * Child component of the ngx-virtual scroller. Used to determine scroll and height.
     * @private
     */
    private virtualScroller;
    /**
     * Semaphore to stop accessing checkbox value a second time.
     * @internal
     */
    private checkboxSemaphore;
    /**
     * Checks if content is initialized
     * @internal
     */
    private initialized;
    /**
     * Subscriptions
     * @internal
     */
    private subscriptions;
    /**
     * The element reference.
     * @private
     */
    private elementRef;
    /**
     * The zone to run the resize observer.
     * @private
     */
    private zone;
    /**
     * Observers the size of the data items list to handle the scrollbar and set the width of the data items list.
     * @internal
     */
    private observer;
    /**
     * Initializes the data items list component.
     * @internal
     */
    ngOnInit(): void;
    /**
     * Detects changes of the input values.
     * @internal
     * @param {SimpleChanges} changes The changed input values.
     */
    ngOnChanges(changes: SimpleChanges): void;
    /**
     * Sets the visual state of the data items list.
     * Specifically for the compressed view and scrollbar design of the data items list.
     * @internal
     */
    ngAfterViewInit(): void;
    /**
     * Unsubscribes from all subscriptions and unobserved from the resize observer.
     * @internal
     */
    ngOnDestroy(): void;
    /**
     * Depending on the clicked data items button the corresponding event actions will be shown.
     * @param {IInteractedDataItems} event The InterDataItemsModel with the clicked data item and information about the clicked button.
     */
    onDataItemsInteractions(event: IInteractedDataItems): void;
    /**
     * Handler to mark data items, used by the emitter of a single data item.
     * @param {any} item Clicked data item.
     */
    handleMarkedDataItems(item: any): void;
    /**
     * Method to set the state of the toolbar checkbox.
     */
    setToolbarCheckboxState(): void;
    /**
     * Method to handle selected / clicked data items.
     * @param {any} item Clicked data items.
     */
    onSelectClick(item: any): void;
    /**
     * Method to handle selected / clicked data items.
     * @param {any} item Clicked data item.
     */
    onShiftDataItemClick(item: any): void;
    /**
     * Method to handle scroll change.
     */
    onScroll(): void;
    /**
     * Method to get data item by name.
     * @param {string} item Item name from the data item.
     */
    getFormGroupDataItemByID(item: string): FormGroup | null;
    /**
     * Auxiliary method to check if the data item is marked.
     * @param inboxId Data item id of the chosen data item.
     */
    checkIfDataItemMarked(inboxId: string): boolean;
    /**
     * Handles the interaction of one checkbox in the data items list.
     * @param event
     */
    onCheckboxInteraction(event: {
        checkedValue: boolean;
        dataItem: any;
    }): void;
    /**
     * Sets the locked data items for the data item list.
     * @param lockedDataItems The locked data items.
     */
    setLockedDataItem(lockedDataItems: IDataItemId[]): void;
    /**
     * Gets the locked data items for the data item list.
     * @param lockedDataItems The locked data items.
     */
    getLockedDataItemInboxIdList(lockedDataItems?: IDataItemId[]): any[];
    /**
     * Gets the locked data item for the given item element.
     * @param itemInboxId The inbox id of the item.
     */
    getLockedDataItem(itemInboxId: string): boolean;
    /**
     * Auxiliary method to mark chosen data item.
     * @param {string} id Data item name of the marked data item.
     * @private
     * @internal
     */
    private markDataItem;
    /**
     * Auxiliary method to unmark chosen data item.
     * @param {string} id Data item name of the unmarked data item.
     * @private
     * @internal
     */
    private unmarkDataItem;
    /**
     * Auxiliary method to get the chosen data item.
     * @param {string} id Data item name of the chosen data item.
     * @private
     * @internal
     */
    private getMarkedDataItem;
    /**
     * Auxiliary method to check if data item is contained in data items.
     * @param {string} id Data item name of the chosen data item.
     * @private
     * @internal
     */
    private containsDataItem;
    /**
     * Auxiliary method to get the number of marked data items.
     * @private
     * @internal
     */
    private numberMarkedDataItems;
    static ɵfac: i0.ɵɵFactoryDeclaration<DataItemsListComponent, never>;
    static ɵcmp: i0.ɵɵComponentDeclaration<DataItemsListComponent, "talenra-data-items-list", never, { "dataItems": { "alias": "dataItems"; "required": false; }; "selectedDataItem": { "alias": "selectedDataItem"; "required": false; }; "selectedMainAttributes": { "alias": "selectedMainAttributes"; "required": false; }; "pairingAttributes": { "alias": "pairingAttributes"; "required": false; }; "scrollToIndex": { "alias": "scrollToIndex"; "required": false; }; "lockedDataItems": { "alias": "lockedDataItems"; "required": false; }; "mainCheckboxState": { "alias": "mainCheckboxState"; "required": false; }; }, { "clickedDataItem": "clickedDataItem"; "dataItemsInteractions": "dataItemsInteractions"; "virtualScrollChange": "virtualScrollChange"; "numberMarkedDataItemsChange": "numberMarkedDataItemsChange"; "mainCheckboxStateChange": "mainCheckboxStateChange"; }, never, ["[further-actions-menu]"], true, never>;
}
