import { EventEmitter, OnChanges, OnInit, SimpleChanges } from '@angular/core';
import { FormControl, FormGroup } from '@angular/forms';
import { MatSnackBar } from '@angular/material/snack-bar';
import { BehaviorSubject } from 'rxjs';
import { CdkDragDrop } from '@angular/cdk/drag-drop';
import { MatMenuTrigger } from '@angular/material/menu';
import { PresetsService } from './presets.service';
import { KeyboardService } from '../../inbox/services/keyboard.service';
import { FilterToolbarService } from '../../filter-toolbar/filter-toolbar.service';
import { UpdatePresetsService } from '../../inbox/services/update-presets.service';
import { InboxState } from '../../inbox/state/inbox.state';
import { IPresetGroup } from '../../shared/interfaces/preset-group.interface';
import { ChangedPresetValuesService } from '../../inbox/services/changed-preset-values.service';
import { IPreset } from '../../shared/interfaces/preset.interface';
import * as i0 from "@angular/core";
export declare class PresetsComponent implements OnInit, OnChanges {
    /**
     * The incoming presetGroups to find with the activePresetName the necessary preset.
     */
    presetGroups: IPresetGroup[];
    /**
     * EventEmitter for the interactions with the preset.
     */
    presetInteractions: EventEmitter<string>;
    /**
     * Child of the toolbar mat-menu.
     */
    talenraInboxPresetMenuTrigger: MatMenuTrigger | undefined;
    /**
     * Input field to save preset.
     */
    savePresetInput: any;
    /**
     * Input field to save preset.
     */
    saveNewPresetInput: any;
    /**
     * The index of the preset that is currently edited corresponding with the order in the presetGroups.
     */
    indexOfPresetInEditing: number;
    /**
     * The index of the group that is currently edited corresponding with the order in the presetGroups.
     */
    indexOfPresetGroupInEditing: number;
    /**
     * Value if the check value is clicked, to change the style of the clicked button.
     */
    onCheckClick: boolean;
    /**
     * Name of the active preset.
     */
    activePresetName: string[];
    /**
     * Save the input of presets.
     */
    presetMenuForm: FormGroup<{
        fcn: FormControl<string | null>;
    }>;
    /**
     * Save the input of new presets.
     */
    saveNewPresetMenuForm: FormGroup<{
        fcn: FormControl<string | null>;
    }>;
    /**
     * In many scenarios, the delete button int the preset menu should be hidden.
     * This map stores the information if the delete button should be shown or not.
     */
    showDeleteButton: Map<string, boolean>;
    /**
     * Map to store the expanded state of the accordion groups.
     */
    expandedGroup: Map<string, boolean>;
    /**
     * Value if the drag and drop is disabled, if the preset is edited through name change and deletion process.
     */
    dragAndDropDisabled: boolean;
    /**
     * Value if an item is dragged.
     * Used to disable the hover effect on non dragged items from other lists.
     */
    draggingState: boolean;
    /**
     * BehaviorSubject for edit state if a preset is currently edited and the other should not be interactable.
     */
    editState: BehaviorSubject<boolean>;
    /**
     * This array will store the extracted values from the presetGroups.
     */
    originalPresetGroupNames: {
        groupName: string;
        presetNames: string[];
    }[];
    /**
     * The filter toolbar service.
     * @internal
     */
    filterToolbarService: FilterToolbarService;
    /**
     * The preset service.
     * @internal
     */
    presetsService: PresetsService;
    /**
     * The keyboard service.
     * @internal
     */
    keyboardService: KeyboardService;
    /**
     * The update preset service.
     * @internal
     */
    updatePresetsService: UpdatePresetsService;
    /**
     * The state service.
     * @internal
     */
    inboxState: InboxState;
    /**
     * The changed values service.
     * @internal
     */
    changedPresetValuesService: ChangedPresetValuesService;
    /**
     * The snackbar service.
     * @internal
     * @TODO: replace with talenra injectors as soon as they are available
     */
    _snackBar: MatSnackBar;
    /**
     * Information if it is possible to save a new preset.
     * @private
     */
    private saveNewPresetButtonIsDisabled;
    /**
     * Information if it is possible to save an existing preset.
     * @private
     */
    private overwritePresetButtonIsDisabled;
    /**
     * Information about the visibility of the presets.
     * The first value is the name of the group, the second value is the name of the preset and the third value is the visibility of the preset.
     * @private
     */
    private visibilityOfPresets;
    /**
     * The subscriptions of the inbox toolbar component.
     * @internal
     * @private
     */
    private subscriptions;
    /**
     * Initializes the inbox toolbar component.
     * @internal
     */
    ngOnInit(): void;
    /**
     * Handles the changes of the presetGroups.
     * @param changes The changes of the presetGroups.
     * @internal
     */
    ngOnChanges(changes: SimpleChanges): void;
    /**
     * Handles the value of presetMenuForm to the presets.
     */
    onPresetFormSubmit(): void;
    /**
     * Handles new values of presetMenuForm to the presets.
     */
    saveNewPresetFormSubmit(): void;
    /**
     * To change the array place of dragged item.
     * @param event The dragged item.
     * @internal
     */
    drop(event: CdkDragDrop<string>): void;
    /**
     * Presets are readonly by default. Only if the preset is edited, the preset is editable.
     * @param groupIndex The index of the group.
     * @param presetIndex The index of the preset.
     * @param event The mouse event.
     */
    setTextAreaReadOnly(groupIndex: number, presetIndex: number, event: Event): void;
    /**
     * To change the name of a preset and make only one preset editable.
     * @param groupName The name of the group.
     * @param oldPresetName The old name of the preset.
     * @param newPresetName The new name of the preset.
     */
    renamingPreset(groupName: string, oldPresetName: string, newPresetName: string): void;
    /**
     * To change the array place of presets.
     * @param groupName The name of the group.
     * @param preset The preset that will be moved.
     * @param direction The direction of the movement.
     */
    updatePresetPosition(groupName: string, preset: IPreset, direction: 'up' | 'down'): void;
    /**
     * Delete presets and emit it to the presets.
     * @param groupName The name of the group that contains the preset.
     * @param presetName The name of the preset that will be deleted.
     * @param event The mouse event.
     */
    deletePreset(groupName: string, presetName: string, event: MouseEvent): void;
    /**
     * Check and save the visibility of the preset.
     * @param bool The visibility of the preset.
     * @param groupName The name of the group.
     * @param presetName The name of the preset.
     */
    checkIfPresetIsVisible(bool: boolean, groupName: string, presetName: string): void;
    /**
     * A button to confirm to delete of a preset is shown.
     * @param bool Determines if the button is shown or not.
     * @param groupName The name of the group.
     * @param presetName The name of the preset.
     * @param event The mouse event.
     */
    confirmDeletePreset(bool: boolean, groupName: string, presetName: string, event: MouseEvent): void;
    /**
     * What happens when the menu is opened.
     */
    onMenuOpened(): void;
    /**
     * What happens when the menu is closed.
     */
    onMenuClosed(): void;
    /**
     * check if it is possible to save a new presetName in an existing preset
     */
    savePresetName(): boolean;
    /**
     * check if it is possible to save a new presetName in a new preset
     */
    saveNewPresetName(): boolean | "" | undefined;
    /**
     * Handling of an accordion header click.
     * @param groupName The name of the group.
     */
    onAccordionClick(groupName: string): void;
    /**
     * Handling the change in the edit state if clicked on all elements except the text area.
     * @param event The mouse event.
     * @param nextState The next state of the edit state.
     */
    changeEditState(event: MouseEvent, nextState: boolean): void;
    /**
     * Handling of a click on the text area of a preset name.
     * Stops propagation if the preset is currently edited.
     * @param event The mouse event.
     * @param presetIndex The index of the preset.
     * @param groupIndex The index of the group.
     */
    clickTextAreaName(event: MouseEvent, presetIndex: number, groupIndex: number): void;
    /**
     * Handling the enter press during the renaming of a preset.
     *
     * @param event The keyboard event.
     * @param group The group of the presets.
     * @param optionName The name of the preset.
     * @param inputText The text of the input.
     */
    checkAndRenamePreset(event: Event, group: string, optionName: string, inputText: string): void;
    /**
     * Disable drag and drop if there is only one preset in the group
     * @param group The group of the presets
     * @internal
     */
    disableDragAndDropFunction(group: IPresetGroup): boolean;
    /**
     * Stop the tab press from closing the material menu.
     * @param keyEvent The event that will be stopped.
     */
    stopTabClosingMenu(keyEvent: Event): void;
    /**
     * Handles the drag start event.
     * Used to set the dragging state to true.
     */
    dragStarted(): void;
    /**
     * Handle the snackbar message.
     * @param message The message that will be displayed in the snackbar.
     * @private
     */
    private openSnackBarPreset;
    /**
     * Open or close the preset menu.
     * @param open Determines if the preset menu is open or not.
     * @private
     */
    private openClosePresetWindow;
    /**
     * Update the textarea value if the preset is currently edited.
     * @param groupIndex The index of the group.
     * @private
     */
    private updateTextareaValue;
    /**
     * Determines the preset is saved by pressing of the enter key.
     * @internal
     * @private
     */
    private savePresetOnEnter;
    /**
     * Closes preset menus after a delay of 1000ms.
     * @internal
     * @private
     */
    private closePresetMenusAfterDelay;
    /**
     * Emits an icon button event.
     * @param presetInteraction The name of the icon button to emit.
     * @emits
     * @private
     */
    private emitPresetInteractions;
    /**
     * Initializes the component.
     * @private
     */
    private initializeComponent;
    static ɵfac: i0.ɵɵFactoryDeclaration<PresetsComponent, never>;
    static ɵcmp: i0.ɵɵComponentDeclaration<PresetsComponent, "talenra-presets", never, { "presetGroups": { "alias": "presetGroups"; "required": false; }; }, { "presetInteractions": "presetInteractions"; }, never, never, true, never>;
}
