import { ChangeDetectorRef, ElementRef, EventEmitter, OnChanges, OnDestroy, OnInit, SimpleChanges } from '@angular/core';
import { PaginatorState } from '@talenra/ngx-base/paginator';
import { IQueryBuilderPossibleRule, IQueryBuilderQuery, IQueryBuilderValueOptions } from '@talenra/ngx-base/query-builder';
import { KeyboardService } from './services/keyboard.service';
import { ChangedPresetValuesService } from './services/changed-preset-values.service';
import { UpdatePresetsService } from './services/update-presets.service';
import { MainFacadeSetterService } from './services/main-facade-setter.service';
import { CsvService } from './services/csv.service';
import { InboxHelperService } from './services/inbox-helper.service';
import { InboxState } from './state/inbox.state';
import { FilterToolbarService } from '../filter-toolbar/filter-toolbar.service';
import { IAttributeItem } from '../shared/interfaces/attribute-item.interface';
import { IInteractedDataItems } from '../shared/interfaces/interacted-data-items.interface';
import { DataItemsClass } from '../shared/classes/dataItem.class';
import { IAttributeItemInput } from '../shared/interfaces/attribute-item-input.interface';
import { IPairingAttributes } from '../shared/interfaces/pairing-attributes.interface';
import { IPresetGroup } from '../shared/interfaces/preset-group.interface';
import { PresetsService } from '../inbox-toolbar/presets-menu/presets.service';
import { IPreset } from '../shared/interfaces/preset.interface';
import { INoteBoxItem } from '../shared/interfaces/note-box-item.interface';
import { IDataItemId } from '../shared/interfaces/data-item-id.interface';
import { CheckboxState } from '../shared/types/checkbox.types';
import { InboxDetailViewService } from '../inbox-layout/inbox-detail-view/inbox-detail-view.service';
import { DataItemsService } from '../inbox-layout/data-items-list/data-items.service';
import { InboxToolbarService } from '../inbox-toolbar/inbox-toolbar.service';
import { IPresetAction } from '../shared/interfaces/preset-action.interface';
import { IFilterSortSearch } from '../shared/interfaces/filter-search-sort.interface';
import { IInboxTabBarItem } from '../shared/interfaces/inbox-tab-bar-item.interface';
import { IIconInput } from '../shared/interfaces/icon-input.interface';
import { FilterStateService } from '../simple-filter-selection/state/filter.state';
import { TConfigurationPanelBottomBarActions } from '../shared/types/configuration-panel.types';
import { IFilterAttribute } from '../shared/interfaces/filter-attribute.interface';
import { ISortAttributesInput } from '../shared/interfaces/sort-attributes-input.interface';
import * as i0 from "@angular/core";
/**
 * Main Component of the Inbox Library, gives an example layout and functionality for an inbox workspace.
 *
 * ```html
 * <talenra-inbox
 *   class="talenra-inbox"
 *   [dataItems]="dataItems"
 *   [loading]="false"
 *   [attributes]="attributes"
 *   [customShortcuts]="customShortcuts"
 *   [detailViewTabs]="detailViewTabs"
 *   [presets]="presets"
 *   [activePresetName]="activePresetName"
 *   (presetAction)="onPresetAction($event)"
 *   (presetsChange)="newPresets($event)"
 *   (clickedDataItemEmitter)="onClickedDataItem($event)"
 *   (dataItemsInteractions)="onDataItemsInteractions($event)"
 *   (virtualScrollerPosition)="onVirtualScrollerPosition($event)"
 * ></talenra-inbox>
 * ```
 */
export declare class InboxComponent implements OnInit, OnChanges, OnDestroy {
    /**
     * Different data items which are used in data items list items and data item information.
     * The data which should be displayed in the inbox.
     *
     * **Important information:**
     *
     * 1. **The Input type is "any[]" so that the inbox can be used with any flattened data structure:**
     * The keys will be used as displayed identifiers for the attributes of the items (the displayedName is able to be customized with the `attributes` input).
     *
     * 2. **The items are not required to have the same data structure:**
     * Attributes of individual items (see example "attribute2 / attribute3") may be missing from item to item.
     * Missing attributes will be displayed as an "–" value.
     *
     * 3. **Attributes with the same key (identifier) have to be of the same type:**
     * Attributes which have the same key (identifier) have to contain the same type of data (e.g. string, number, date). For example `attribute1` are of the same type, here `string`.
     *
     * 4. **The data-items-list has a limited number of attributes for each item:**
     * The `attributes` input can be used to define which attributes should be displayed in the data-items-list or in the detail-view.
     * Default: 12, customizable in the inboxConfiguration of by the presets.
     *
     * 5. **The list items are displayed in a Virtual Scroller:**
     * That means that only the list items which are visible are rendered. This is done to improve the performance of the inbox.
     *
     * 6. **Use attributes input for the complex structure:**
     * If the data has a 'complex' structure and is not flattened, the input `attributes` has to define the identifier to the attribute (see section `attributes`).
     *
     * 7. **If new `dataItems` have to be inputted:**
     * The "refresh" input has be used (set to true) to show the skeleton loading. Otherwise, the new data will not be shown correctly. After the new data is loaded and inputed, the "refresh" input has to be set to false.
     *
     * 8. **The data items are used to fill the single- and multi-select filters:**
     *  If not otherwise specified in the `attributes` input, the data items are used to fill the single- and multi-select filters options.
     *
     * @example
     * <talenra-inbox [attributes]="attributes" [dataItems]="dataItems"></talenra-inbox>
     *
     * @example flattened structure
     * dataItems = [{
     *   attribute1: 'Direkt eingegangene Beschwerde',
     *   attribute2: 'ZH-20230510-0014648',
     *   ...,
     * },
     *   {
     *     attribute1: 'Direkt eingegangene Beschwerde',
     *     attribute3: 'Janssens Mila',
     *     ...,
     *   },
     * ];
     *
     * @example complex structure
     * dataItems = [{
     *   attribute1: 'Direkt eingegangene Beschwerde',
     *   attribute2: 'ZH-20230510-0014648',
     *   attribute3: {
     *     attribute4: 'Janssens Mila',
     *     attribute5: '756.8396.7741.70',
     *   },
     *   ...,
     * },
     *   {
     *     attribute1: 'Direkt eingegangene Beschwerde',
     *     attribute2: 'Janssens Mila',
     *     ...,
     *   },
     * ];
     */
    dataItems: any[];
    /**
     * Data items attributes which are used to configure the specific attribute of the data items and the behavior for the chosen attributes.
     * The inbox focuses on the configuration and display of specific attributes for each data item.
     * The attributes parameter allows for the customization of attributes and their presentation within the inbox.
     * The **IAttributeItemInput** interface is utilized to define the specific attributes of each item.
     *
     * **Important information:**
     *
     * 1. **The naming of the input type has changed: current `AttributeItemInput` to `IAttributeItemInput`**.
     *  The `AttributeItemInput` has the same properties as the `IAttributeItemInput`.
     *
     * @example
     * <talenra-inbox [attributes]="attributes"></talenra-inbox>
     *
     * @example
     * // Import
     * import { IAttributeItemInput } from '@talenra/ngx-inbox';
     *
     * const attributes: IAttributeItemInput[] = [
     *   {
     *     identifier: 'caseFlags',   // required
     *     displayedName: 'Hinweise', // required
     *     defaultAttribute: 'detail', // optional
     *     iconFilter: { // optional
     *       identifier: 'caseFlags',
     *       icon: 'error',
     *       activeIconColor: 'primary',
     *       iconTooltip: 'Hinweis',
     *       displayedString: (elem) => {
     *         return 'Beinhaltet die Rolle MA' + elem['caseFlags'].filter((s: string | string[]) => s.includes('MA')).length;
     *       },
     *       assignmentCondition: (elem) => {
     *         return elem['caseFlags'].filter((s: string | string[]) => s.includes('MA')).length != 0;
     *       },
     *     },
     *   },
     *   // attribute for complex data structure (see section `dataItems`)
     *   {
     *     identifier: 'workflowCase.pvRoles',   // required
     *     displayedName: 'Hinweise', // required
     *     filterable: 'multi-select', // optional
     *     defaultAttribute: 'detail', // optional
     *     singleMultiSelectOptions: ['Mitglied prüfen', 'Lohndeklaration erfassen', 'Partner prüfen'], // optional
     *   },
     *   {
     *     identifier: 'workflowCase.initialElements.partnerFlag',   // required
     *     displayedName: 'Hinweise', // required
     *     filterable: 'multi-select', // optional
     *     allowEmptyDataItemFilter: false, // optional
     *   },
     * ];
     */
    attributes: IAttributeItemInput[];
    /**
     *
     * The presets input is necessary to create and show different presets in the inbox.
     * The user has the possibility to choose between the presets.
     * If the consuming application used the app without the presets input, the inbox won't be able to save or manipulate new presets and existing presets.
     *
     * **Important information:**
     *
     * 1. **The naming of the input type has changed: current `Preset` to `IPreset`**.
     *  The `Preset` has the same properties as the `IPreset`.
     *
     * 2. **Minimum one preset has to be defined with `changeable`: false. That is the default view.**
     *
     * @example
     * <talenra-inbox [attributes]="attributes" [presets]="presets" [activePresetName]="activePresetName"></talenra-inbox>
     *
     * @example
     * const activePresetName = ['Meine Inbox', 'View 1'];
     *
     * @example
     * // Import
     * import { IPreset } from '@talenra/ngx-inbox';
     *
     * const presets: IPreset[] = [{
     *   identifier: '121bd936-ce20-4ea9-9dc1-6cdaf61f9c3d',
     *   name:
     *     'Meine Inbox',
     *   changeable:
     *     false,
     *   selectedAttributes:
     *     [
     *       { identifier: 'case.caseTypeName', defaultAttribute: 'main' },
     *       { identifier: 'case.caseID', defaultAttribute: 'main' },
     *       { identifier: 'processStep', defaultAttribute: 'main' },
     *       { identifier: 'insuree.partnerFlags', defaultAttribute: 'detail' },
     *       { identifier: 'insuree.pvRoles', defaultAttribute: 'detail' },
     *       { identifier: 'case.leadingKpvPartID', defaultAttribute: 'detail' },
     *       { identifier: 'insuree.kpvPartID', defaultAttribute: 'detail' },
     *     ],
     *   children:
     *     [
     *       {
     *         name: 'View 1',
     *         numberMainAttributesChosenByUser: 4,
     *         selectedAttributes: [
     *           { identifier: 'case.caseTypeName', defaultAttribute: 'main' },
     *           { identifier: 'case.caseID', defaultAttribute: 'main' },
     *           { identifier: 'processStep', defaultAttribute: 'detail' },
     *           { identifier: 'insuree.lastNameOrgName', defaultAttribute: 'detail' },
     *           { identifier: 'case.caseStartDate', defaultAttribute: 'detail' },
     *           { identifier: 'member.lastNameOrgName', defaultAttribute: 'detail' },
     *           { identifier: 'insuree.socialSecurityNumber', defaultAttribute: 'detail' },
     *           { identifier: 'case.casePriority', defaultAttribute: 'main' },
     *         ],
     *         sortAttributes: [
     *           { identifier: 'case.caseTypeName', sort: 'asc' },
     *           { identifier: 'insuree.socialSecurityNumber', sort: 'desc' },
     *         ],
     *         filterAttributes: [
     *           {
     *             identifier: 'case.caseTypeName',
     *             value: ['Direkt eingegangene Beschwerde'],
     *           },
     *           {
     *             identifier: 'case.caseStartDate',
     *             value: [new Date('01.15.2020'), new Date('12.30.2023')],
     *           },
     *           { identifier: 'case.casePriority', value: [1, 2] },
     *         ],
     *         iconAttributes: [],
     *       },
     *       {
     *         name: 'View 2',
     *         numberMainAttributesChosenByUser: 4,
     *         selectedAttributes: [
     *           { identifier: 'case.caseTypeName', defaultAttribute: 'main' },
     *           { identifier: 'case.caseID', defaultAttribute: 'main' },
     *           { identifier: 'processStep', defaultAttribute: 'detail' },
     *           { identifier: 'insuree.lastNameOrgName', defaultAttribute: 'detail' },
     *           { identifier: 'case.caseStartDate', defaultAttribute: 'detail' },
     *           { identifier: 'member.lastNameOrgName', defaultAttribute: 'detail' },
     *         ],
     *         sortAttributes: [{ identifier: 'case.caseTypeName', sort: 'asc' }],
     *         filterAttributes: [
     *           {
     *             identifier: 'case.caseTypeName',
     *             value: ['Direkt eingegangene Beschwerde'],
     *           },
     *         ],
     *         iconAttributes: [],
     *       },
     *     ],
     * }];
     */
    presets: IPreset[];
    /**
     * Input `activePresetName` is used to let the inbox know which group or preset was clicked in the app.
     * As the inbox needs to know which group or preset is currently active, activePresetName is provided as an input.
     *
     * If a group is active, then only the group name is filled in the activePresetName input.
     *
     * If a preset is active, then the group name and preset name is filled in the activePresetName input.
     *
     * Most of the time, the active state of the main navigation also have to be set in the consuming app.
     *
     * **Important Information:**
     *
     * 1. **In many cases, `activePresetName` has to be updated after `presets` have been changed.**
     *  The consuming app receives information about what happened to the presets via the presetAction emitter.
     * 2. Also note that the reset button will not work properly if activePresetName is not set correctly.
     *
     * @example
     * <talenra-inbox [attributes]="attributes" [presets]="presets" [activePresetName]="activePresetName"></talenra-inbox>
     *
     * @example
     * // if group is active
     * const activePresetName = ['Meine Inbox'];
     *
     * // if preset in group is active
     * const activePresetName = ['Meine Inbox', 'View 1'];
     */
    activePresetName: string[];
    /**
     * The detailViewTabs input is used to add tabs to the detail-view.
     *
     * **Important information:**
     *
     * 1. **The naming of the input type has changed: current `DetailViewItemModel[]` to `IInboxTabBarItem[]`**.
     *  The `IInboxTabBarItem` has the same properties as the `DetailViewItemModel`.
     *
     * 2. **The "detailViewTabs" <u>will not be displayed</u> in the inbox, if the html tag of the inbox is contained in an `*ngIf` statement.**
     *
     * 3. **The `counter` attribute has to be a behavior subject, because the counter is updated in the inbox component and the detail view component.**
     *
     * 4. **The `counter` has a maximum value of 99. If the counter is higher than 99, the badge will display "99+".**
     *
     * 5. **Because of the Angular lifecycle, the `detailViewTabs` input has a special declaration in the consuming application.**
     *  The IInboxTabBarItem has a TemplateRef as a property, which is only initialized in `afterViewInit` of the consuming app
     *  The consuming application has to declare the TemplateRef as a ViewChild and pass it to the `detailViewTabs` in the ngAfterViewInit method
     *  For more information about the Angular lifecycle, please visit the [Angular documentation](https://angular.io/guide/lifecycle-hooks)
     *  The input property icon is limited by the talenra-icon library (https://gitlab.svanet.ch/talenra/talenra-workspace)
     *
     * 6. **The `useScroll` attribute is used to define if the content of the tab should be scrollable or not.**
     *  If a custom scroll container should be used, the `useScroll` attribute should be set to false.
     *  And the style of the scroll container should be set like in the example.
     *
     * 7. **The recommended number of custom tabs are 5. Otherwise, it would mess with the design.**
     *
     * ```html
     * <talenra-inbox [attributes]="attributes" [detailViewTabs]="detailViewTabs"></talenra-inbox>
     *
     * <ng-template #talenraInboxDocuments>
     *   <talenra-scroll-container class="custom-scroll">
     *     <h1 class="panel-title">Dokumente</h1>
     *     <div [formGroup]="exampleCheckboxForm" class="inline-documents">
     *       <talenra-checkbox fcn="check_1" size="s"></talenra-checkbox>
     *       <p class="pair">
     *         <span class="documents">Lohnbescheinigung</span>
     *         <span class="documents-entry">hinzugefügt am 12.03.2021</span>
     *       </p>
     *     </div>
     *   </talenra-scroll-container>
     * </ng-template>
     * <ng-template #talenraInboxComments>
     *   ...
     * </ng-template>
     * <ng-template #talenraInboxHistory>
     *   ...
     * </ng-template>
     * ```
     *
     * ```typescript
     * import { IInboxTabBarItem } from '@talenra/ngx-inbox';
     *
     * @ViewChild('talenraInboxDocuments', { read: TemplateRef }) talenraInboxDocuments!: TemplateRef<any>;
     * @ViewChild('talenraInboxComments', { read: TemplateRef }) talenraInboxComments!: TemplateRef<any>;
     * @ViewChild('talenraInboxHistory', { read: TemplateRef }) talenraInboxHistory!: TemplateRef<any>;
     *
     * public detailViewTabs: IInboxTabBarItem[] = [];
     *
     * ngAfterViewInit(): void {
     *     // get the template in the next lifecycle hook, because the viewChild is not available yet
     *     Promise.resolve().then(() => {
     *       // create the detail view tabs
     *       this.detailViewTabs: IInboxTabBarItem[] = [
     *         {
     *           label: 'documents',
     *           icon: 'description',
     *           counter: new BehaviorSubject<number>(8),
     *           useScroll: false,
     *           detailViewTabContentTemplate: this.talenraInboxDocuments,
     *         },
     *         {
     *           label: 'comments',
     *           icon: 'chat-bubble-outline',
     *           counter: new BehaviorSubject<number>(100),
     *           useScroll: true,
     *           detailViewTabContentTemplate: this.talenraInboxComments,
     *         },
     *         {
     *           label: 'history',
     *           icon: 'history',
     *           useScroll: false,
     *           detailViewTabContentTemplate: this.talenraInboxHistory,
     *         },
     *       ];
     *     });
     *   }
     *   ```
     *
     *  ```scss
     * .custom-scroll {
     *   position: absolute;
     *   inset: 0;
     * }
     * ```
     */
    detailViewTabs: import("@angular/core").InputSignal<IInboxTabBarItem[]>;
    /**
     * The inboxConfigurationPanelTabs input is used to add tabs to the inboxConfigurationPanel.
     *
     * **Important information:**
     *
     * 1. **The "inboxConfigurationPanelTabs" <u>will not be displayed</u> in the inbox, if the html tag of the inbox is contained in an `*ngIf` statement.**
     *
     * 2. **The `counter` attribute has to be a behavior subject, because the counter is updated in the inbox component and the inbox-configuration-panel component.**
     *
     * 3. **The `counter` has a maximum value of 99. If the counter is higher than 99, the badge will display "99+".**
     *
     * 4. **Because of the Angular lifecycle, the `inboxConfigurationPanelTabs` input has a special declaration in the consuming application.**
     *  The IInboxTabBarItem has a TemplateRef as a property, which is only initialized in `afterViewInit` of the consuming app
     *  The consuming application has to declare the TemplateRef as a ViewChild and pass it to the `inboxConfigurationPanelTabs` in the ngAfterViewInit method
     *  For more information about the Angular lifecycle, please visit the [Angular documentation](https://angular.io/guide/lifecycle-hooks)
     *  The input property icon is limited by the talenra-icon library (https://gitlab.svanet.ch/talenra/talenra-workspace)
     *
     * 5. **The `useScroll` attribute is used to define if the content of the tab should be scrollable or not.**
     *  If a custom scroll container should be used, the `useScroll` attribute should be set to false.
     *  And the style of the scroll container should be set like in the example.
     *
     * ```html
     * <talenra-inbox [attributes]="attributes" [inboxConfigurationPanelTabs]="inboxConfigurationPanelTabs"></talenra-inbox>
     *
     * <ng-template #talenraInboxEnhancedConfiguration>
     *   <talenra-scroll-container class="custom-scroll">
     *     <h1 class="panel-title">Further Configuration</h1>
     *     <div [formGroup]="exampleCheckboxForm" class="inline-documents">
     *       <talenra-checkbox fcn="check_1" size="s"></talenra-checkbox>
     *       <p class="pair">
     *         <span class="documents">Set name</span>
     *         <span class="documents-entry">Enhance Priority Levels</span>
     *       </p>
     *     </div>
     *   </talenra-scroll-container>
     * </ng-template>
     * ```
     *
     * ```typescript
     * import { IInboxTabBarItem } from '@talenra/ngx-inbox';
     *
     * @ViewChild('talenraInboxEnhancedConfiguration', { read: TemplateRef }) talenraInboxEnhancedConfiguration!: TemplateRef<any>;
     *
     * public inboxConfigurationPanelTabs: IInboxTabBarItem[] = [];
     *
     * ngAfterViewInit(): void {
     *     // get the template in the next lifecycle hook, because the viewChild is not available yet
     *     Promise.resolve().then(() => {
     *       // create the inboxConfigurationPanelTabs
     *       this.detailViewTabs: IInboxTabBarItem[] = [
     *         {
     *           label: 'documents',
     *           icon: 'description',
     *           counter: new BehaviorSubject<number>(8),
     *           useScroll: false,
     *           detailViewTabContentTemplate: this.talenraInboxEnhancedConfiguration,
     *         },
     *         ...
     *       ];
     *     });
     *   }
     *   ```
     *
     *  ```scss
     * .custom-scroll {
     *   position: absolute;
     *   inset: 0;
     * }
     * ```
     */
    inboxConfigurationPanelTabs: import("@angular/core").InputSignal<IInboxTabBarItem[]>;
    /**
     * Boolean to show if skeleton loading is to be shown.
     *
     * **Important information:**
     *
     * 1. The inbox can **not** detect the loading state of the data items, so the "refresh" input has to be used.
     */
    loading: boolean;
    /**
     * The pairing attributes which combine two attributes to one attribute.
     *
     * The pairingAttributes input is used to combine two attributes to one attribute.
     *
     * **Important information:**
     *
     * 1. **The naming of the input type has changed: current `PairingAttributesModel` to `IPairingAttributes`**.
     *  The `PairingAttributesModel` has the same properties as the `IPairingAttributes`.
     *
     * @example
     * <talenra-inbox [attributes]="attributes" [pairingAttributes]="pairingAttributes"></talenra-inbox>
     *
     * @example
     * import { IPairingAttributes } from '@talenra/ngx-inbox';
     *
     * pairingAttributes: IPairingAttributes[] = [
     *     {
     *       identifier: 'combinedName',
     *       displayedName: 'First/Last Name',
     *       firstAttribute: 'firstNameOrgNameAddOn',
     *       secondAttribute: 'lastNameOrgName',
     *       commaSeparation: false,
     *     },
     *     {
     *       identifier: 'member.combinedName',
     *       displayedName: 'Member First/Last Name',
     *       firstAttribute: 'member.lastNameOrgName',
     *       secondAttribute: 'member.firstNameOrgNameAddOn',
     *       commaSeparation: true,
     *     },
     *   ];
     */
    pairingAttributes: IPairingAttributes[];
    /**
     * The NoteBoxItems input is used to show a custom note box items in style of the default note box.
     *
     * It is changeable in runtime by the consuming app to show different content in the note box.
     *
     * **Important information:**
     *
     * 1. **The naming of the input type has changed: current `NoteBoxItem` to `INoteBoxItem`**.
     *  The `NoteBoxItem` has the same properties as the `INoteBoxItem`.
     *
     * @example
     * <talenra-inbox [attributes]="attributes" [noteBoxItems]="noteBoxItems"></talenra-inbox>
     *
     * @example
     * import { INoteBoxItem } from '@talenra/ngx-inbox';
     *
     * noteBoxItems: INoteBoxItem[] = [
     *    {
     *    identifier: 'Note 1',
     *    icon: 'info',
     *    iconColor: 'primary',
     *    content: 'This is a note box item.',
     *    },
     *    {
     *    identifier: 'Note 2',
     *    icon: 'beach-access',
     *    iconColor: 'status-red',
     *    content: 'This is another note box item.',
     *    }
     *   ];
     */
    noteBoxItems?: INoteBoxItem[];
    /**
     * The `refreshing` input boolean allows the consuming application to set the inbox into a refreshing state.
     * If the value `true` is injected and the inbox is filled with data (data items), the skeleton loading will be shown.
     * The consuming app can now load new data (dataItems) and input it to the inbox.
     * After the refreshing value can be set to `false` again.
     * Set, if necessary, the `selectedDataItem` input to the data item which was selected before the refresh.
     * The new data (dataItems) will be shown and all filter and sort will be reset to the default value.
     *
     * #### Important information
     *
     * 1. **The consuming app has to save the selected data Item (`clickedDataItemEmitter` Output) and set it again after the refresh with the `selectedDataItem` Input.**
     */
    refreshing: boolean;
    /**
     * The input is used to select a data item in the inbox. The input is an object of `DataItemIdModel`.
     * The identifier is the key in the data item which to get the value of the data item.
     * The value is the compared value which is to be compared.
     *
     * **Important information:**
     *
     * 1. **The naming of the input type has changed: current `DataItemIdModel` to `IDataItemId`**.
     *  The `DataItemIdModel` has the same properties as the `IDataItemId`.
     *
     * @example
     * <talenra-inbox [attributes]="attributes" [selectedDataItem]="selectedDataItem"></talenra-inbox>
     *
     * @example
     * import { DataItemIdModel } from '@talenra/ngx-inbox';
     *
     * selectedDataItem: DataItemIdModel = {
     *  identifier: 'case.caseID',
     *  value: 'ZH-20230510-0014648',
     *  };
     */
    selectDataItem?: IDataItemId;
    /**
     * The input is used to lock specific data items in the inbox. The input is an array of `DataItemIdModel`.
     * The items will be locked visually in the inbox and the user can not interact with them.
     * Additionally, because the data item is not selectable the detail view will not show any information of the data item.
     *
     * **Important information:**
     *
     * 1. **The naming of the input type has changed: current `DataItemIdModel` to `IDataItemId`**.
     *  The `DataItemIdModel` has the same properties as the `IDataItemId`.
     *
     * @example
     * <talenra-inbox [attributes]="attributes" [lockedDataItems]="lockedDataItems"></talenra-inbox>
     *
     * @example
     * import { DataItemIdModel } from '@talenra/ngx-inbox';
     *
     * lockedDataItems: DataItemIdModel[] = [
     *  {
     *    identifier: 'case.caseID',
     *    value: 'ZH-20230510-0014648',
     *  },
     *  {
     *    identifier: 'case.caseID',
     *    value: 'ZH-20230510-0014649',
     *  },
     * ];
     */
    lockedDataItems: IDataItemId[];
    /**
     * If true, the pagination feature is enabled.
     *
     * @example
     * <talenra-inbox [attributes]="attributes" usePagination>
     *   ...
     * </talenra-inbox>
     */
    usePagination: boolean;
    /**
     * The number of items per page in the pagination.
     *
     * @example
     * <talenra-inbox [attributes]="attributes" [paginatorState]="paginatorState" usePagination></talenra-inbox>
     */
    paginatorState: PaginatorState;
    /**
     * The query that is currently selected.
     */
    query: import("@angular/core").ModelSignal<IQueryBuilderQuery>;
    /**
     * The possible rules that can be selected.
     */
    possibleRules: import("@angular/core").InputSignal<IQueryBuilderPossibleRule[]>;
    /**
     * The values that can be selected in connection to each rule identifier.
     */
    possibleOptions: import("@angular/core").InputSignal<IQueryBuilderValueOptions[]>;
    /**
     * Emits the active item, enables the consuming app to call appropriate api calls etc. (e.g. to change the content of the detail-view tabs).
     *
     * The clickedDataItemEmitter is used to get the clicked/active item, which is emitted as an object.
     * The intended purpose is to allow the consuming app get detail-view-data of the specific item.
     *
     * **Important information:**
     *
     * 1. **If the emitter returns the value undefined no data item is selected (no data item for selection available).**
     * 2. **The consuming application should adjust the detail view accordingly.**
     */
    clickedDataItemEmitter: EventEmitter<any>;
    /**
     * The event which is emitted when a dataItems is interacted with by the further-actions and the proceed button.
     *
     * The Messages correlate with the buttons in the toolbar and the list view.
     * Process: The process button was clicked (arrow-right icon).
     * More: The further actions button was clicked (three-dots icon).
     *
     * The More message is intended to allow the consuming app to customize the further actions menu and specify which item opened the menu.
     *
     * **Important information:**
     *
     * 1. **The naming of the input type has changed: current `InteractedDataItemsModel` to `IInteractedDataItems`**.
     *  The `InteractedDataItemsModel` has the same properties as the `IInteractedDataItems`.
     *
     */
    dataItemsInteractions: EventEmitter<IInteractedDataItems>;
    /**
     * The event which is emitted when a preset is created, updated or deleted.
     *
     * The consuming application receives information about which operation is used with the preset and the modified presets.
     * The consuming app should save the presets and make the preset accessible through SidenavItems in the app.component (talenra-app-frame).
     *
     * **Important information:**
     *
     * 1. **The naming of the input type has changed: current `PresetAction` to `IPresetAction`**.
     *  The `PresetAction` has the same properties as the `IPresetAction`.
     *
     * 2. **The consuming app has to input the modified presets to the inbox.**
     *
     * 3. **`activePresetName` input has to be updated in following cases.**
     *
     * - create --> switch to the new preset (presetName sent in the `presetAction` emitter)
     * - update --> switch to the updated preset (presetName sent in the `presetAction` emitter)
     * - update & rename --> switch to the updated preset (presetName sent in the `presetAction` emitter)
     * - delete --> switch to the first <u>unchangeable</u> preset of the `presets`. For example, activate group of the preset.
     * - visibility-off --> switch to the first <u>unchangeable</u> preset of the `presets`. For example, activate group of the preset.
     */
    presetAction: EventEmitter<IPresetAction>;
    /**
     * The event which is emitted when the virtual scroller position changes.
     *
     * The virtualScrollerPosition is used to get the position of the virtual scroll.
     * The position is emitted as a number value ranging from -2 to x.
     *
     * - Values from 1 to x are the position of the virtual scroll.
     * - The value 0 indicates that the virtual scroll is at the top.
     * - The value -1 indicates that the virtual scroll has no scrollable content.
     * - The value -2 indicates that the virtual scroll has detected a buggy behaviour (loop scroll).
     * - If the value -2 the consuming app hast to stop the possible resizing of the inbox.
     *
     * @example
     * <talenra-workspace-simple>
     *   <div class="inbox-app">
     *     <talenra-workspace-header
     *       [path]="workspacePath"
     *       [title]="workspaceTitle"
     *       class="page-header"
     *       [class.header-hidden]="!headerEdgeCase && headerHidden && !noScroll"></talenra-workspace-header>
     *     <talenra-inbox [attributes]="attributes" class="talenra-inbox" (virtualScrollerPosition)="onVirtualScrollerPosition($event)"></talenra-inbox>
     *   </div>
     * </talenra-workspace-simple>
     *
     * @example
     * .inbox-app {
     *   display: flex;
     *   flex-wrap: nowrap;
     *   flex-direction: column;
     *   height: 100%;
     *   width: 100%;
     * }
     *
     * .page-header {
     *   margin-left: 20px;
     *   opacity: 1;
     *   height: 92px;
     *
     *   transition: height 0.3s, opacity 0.3s;
     *
     *   &.header-hidden {
     *     opacity: 0;
     *     height: 0;
     *   }
     * }
     *
     * .talenra-inbox {
     *   position: relative;
     *   flex-grow: 1;
     * }
     *
     * @example
     *
     * headerHidden = false;
     * noScroll = false;
     * headerEdgeCase = false;
     *
     * onVirtualScrollerPosition(event: number): void {
     *     switch (event) {
     *       case -2:
     *         // if the value -2 is emitted, the inbox has a buggy loop, the header should be fixed and not be trying to hide for the remaining usage
     *         this.headerEdgeCase = true;
     *         break;
     *       default:
     *         // if the value -1 is emitted, the inbox has a buggy loop, the header should be fixed because the inbox is not scrollable (to few items)
     *         this.noScroll = event === -1;
     *         // if the value 0 is emitted, the inbox is at the top and the header should be fixed
     *         // if the value > 0 is emitted, the inbox is not at the top and the header should be hidden
     *         this.headerHidden = event > 0;
     *         break;
     *     }
     *   }
     */
    virtualScrollerPosition: EventEmitter<number>;
    /**
     * The event which is emitted when the selected main attributes change
     *
     * The consuming application receives information about which main attributes (the ones above the line in the attribute-settings).
     * The attributes are emitted as an array of strings with the correct order as chosen by the user. The strings are the identifiers of the attributes.
     */
    selectedMainAttributesEmitter: EventEmitter<string[]>;
    /**
     * The event which is emitted when the selected detail attributes changes
     *
     * The consuming application receives information about which detail attributes (the ones below the line in the attribute-settings).
     * The attributes are emitted as an array of strings with the correct order as chosen by the user. The strings are the identifiers of the attributes.
     */
    selectedDetailAttributesEmitter: EventEmitter<string[]>;
    /**
     * The event which is emitted when the all selected attributes changes
     *
     * The consuming application receives information about which attributes have been selected.
     */
    selectedAllAttributesEmitter: EventEmitter<string[]>;
    /**
     * The event which is emitted when the filter, sort or the search input changes
     *
     * The consuming application receives information about which filter, sort or search input is used.
     *
     * **Important information:**
     *
     * 1. **The naming of the input type has changed: current `FilterSortSearchModel` to `IFilterSortSearch`**.
     *  The `FilterSortSearchModel` has the same properties as the `IFilterSortSearch`.
     */
    filterSortSearchEmitter: EventEmitter<IFilterSortSearch>;
    /**
     * The value that the refresh button is clicked.
     *
     * It will emit the value `true` when the refresh button is clicked.
     * The consuming application can load the data and set the value to `false` again.
     */
    refreshingChange: EventEmitter<boolean>;
    /**
     * The event which is emitted when the page changes in the pagination.
     * The consuming application receives information about which page is selected.
     * The consuming application can load the data for the selected page by using the `refresh`.
     */
    paginatorStateChange: EventEmitter<PaginatorState>;
    /**
     * Class to interact with data items.
     */
    dataItemsClass: DataItemsClass;
    /**
     * Number of marked data items in data items list.
     */
    numberMarkedDataItems: number;
    /**
     * Number of marked data items in data items list.
     */
    mainCheckboxState: CheckboxState;
    /**
     * information if in attributes, attributesDetails, numberMainAttributesChosenByUser, sortFilter or filter changes are made.
     * string: attributes, attributesDetails, numberMainAttributesChosenByUser, sortFilter or filter
     * boolean: true if changes are made, false if no changes are made
     */
    changedValuesInPresetGroups: Map<string, boolean>;
    /**
     * flag to check, if all attributes are selected or not in attributeSettings.
     * If the flag is the same as the length of the attributes, then the setBufferFilterSort is not updated.
     */
    allSelectedAttributesIdentifiers: string[];
    /**
     * The transformed Preset[] to the necessary format.
     */
    transformedPresetGroups: IPresetGroup[] | undefined;
    /**
     * Injected inbox toolbar service.
     */
    inboxToolbarService: InboxToolbarService;
    /**
     * Injected keyboard service.
     */
    keyboardService: KeyboardService;
    /**
     * Injected changed values service.
     */
    changedValuesService: ChangedPresetValuesService;
    /**
     * Injected filter toolbar service.
     */
    filterToolbarService: FilterToolbarService;
    /**
     * Injected update preset service.
     */
    updatePresetsService: UpdatePresetsService;
    /**
     * Injected set inbox configuration service.
     */
    mainFacadeSetterService: MainFacadeSetterService;
    /**
     * Injected csv service.
     */
    csvService: CsvService;
    /**
     * Injected inbox helper service.
     */
    inboxHelperService: InboxHelperService;
    /**
     * Injected presets service.
     */
    presetsService: PresetsService;
    /**
     * Injected inbox state.
     */
    inboxState: InboxState;
    /**
     * Injected filter state.
     */
    filterState: FilterStateService;
    /**
     * Injected inbox detail view service.
     */
    inboxDetailViewService: InboxDetailViewService;
    /**
     * Injected inbox data items service.
     */
    dataItemsService: DataItemsService;
    /**
     * The change detector reference.
     * @internal
     */
    changeDetectorRef: ChangeDetectorRef;
    /**
     * The computed inbox detail view tabs. Resets the detail view tabs and sets the proper values.
     */
    protected inboxDetailViewTabs: import("@angular/core").Signal<IInboxTabBarItem[]>;
    /**
     * The subscription for the inbox.
     * @internal
     */
    private subscriptions;
    /**
     * The subscriptions for the presets.
     * @internal
     */
    private presetSubscriptions;
    /**
     * The subscriptions of the detail view.
     * @internal
     */
    private detailViewSubscriptions;
    /**
     * The subscriptions of the inbox to handle the change in the state of loading and the preset change by the active preset name.
     * @internal
     */
    private initializationSubscriptions;
    /**
     * Constructor of the inbox component.
     * @internal
     * */
    constructor(elementRef: ElementRef);
    /**
     * Initializes the inbox component.
     * @internal
     */
    ngOnInit(): void;
    /**
     * Initializes the component for the view usage.
     */
    initializeComponentForViewUsage(): void;
    /**
     * Functions to initialize the component.
     */
    initializeComponent(): void;
    /**
     * Detects changes in the input values.
     * @param changes The changes.
     * @internal
     **/
    ngOnChanges(changes: SimpleChanges): void;
    /**
     * Unsubscribes from all subscriptions.
     * @internal
     **/
    ngOnDestroy(): void;
    /**
     * Main function to handle interactions with clicked icon buttons.
     * @param btn The clicked button.
     */
    iconBtnFunction(btn: string): void;
    handleChangesOnPreset(btn: string, attributesUsed?: boolean): void;
    /**
     * Event emitter for changes in the preset.
     */
    callbackFunctionForPresetChanges(): void;
    /**
     * Depending on the clicked data item button the corresponding event actions will be shown.
     * @param {IInteractedDataItems} event The interacted data items event.
     */
    onDataItemsInteractions(event: IInteractedDataItems): void;
    /**
     * Auxiliary method to set the attributeSortOrFilterUsedSubject.
     */
    setAttributeSortOrFilterUsedSubjectFunction(): void;
    /**
     * Handler for the selected main attributes.
     * @param selectedMainAttributes Selected main attributes.
     */
    selectedMainAttributesEmitterHandler(selectedMainAttributes: IAttributeItem[]): void;
    /**
     * Handler for the selected detail attributes.
     * @param selectedDetailAttributes Selected detail attributes.
     */
    selectedDetailAttributesEmitterHandler(selectedDetailAttributes: IAttributeItem[]): void;
    /**
     * Handler for the selected all attributes.
     * @param selectedAllAttributes Selected all attributes.
     */
    selectedAllAttributesHandler(selectedAllAttributes: IAttributeItem[]): void;
    /**
     * Sets the number of main attributes chosen by the user.-
     * @param $event The number value that is chosen by the user to show the main attributes.
     */
    numberMainAttributesChosenByUserHandler($event: number): void;
    /**
     * Handler if the inbox is to be reset.
     */
    resetPresetEmitterHandler(): void;
    /**
     * Handler for the clicked data item.
     * @param dataItem The clicked data item.
     */
    clickedDataItemFunction(dataItem: any): void;
    /**
     * Handler for the change of number of marked data items.
     * @param $event
     */
    numberMarkedDataItemsChange($event: number): void;
    /**
     * An interface to transform the delivered presets: Preset[] into the necessary PresetGroup[] format.
     * @param presets The presets which are delivered.
     * @param parentGroupName The name of the parent group.
     * @returns The transformed presets.
     */
    transformPresetsToPresetGroups(presets: IPreset[], parentGroupName?: null): IPresetGroup[];
    /**
     * An interface to transform the preset: PresetGroup[] into the necessary Preset[] format
     * to send it to the consuming application.
     * @param presetGroups The preset which are delivered.
     * @returns The transformed preset.
     */
    transformPresetGroupsToPresets(presetGroups: IPresetGroup[]): IPreset[];
    /**
     * Subscribes to the changes in the inbox. Values are provided by the changed values service.
     */
    recognizeChangesInInbox(): void;
    /**
     * Handler for the paginator state change.
     * @param paginatorState The paginator state.
     */
    onPaginatorStateChange(paginatorState: PaginatorState): void;
    /**
     * Actions performed on button action.
     * Should emit filterSearchSort event.
     * @param action The performed action.
     */
    onInboxConfigurationPanelButtonAction(action: TConfigurationPanelBottomBarActions): void;
    /**
     * Handler for changes in the icon filter state.
     * @param icons All the icons with the updated active state.
     */
    onIconFilterChange(icons: IIconInput[]): void;
    /**
     * The action that is to be performed in for the items.
     * @param filterAttributes The selected filter attributes.
     */
    onSelectedFilters(filterAttributes: IFilterAttribute[]): void;
    /**
     * Handles the selected sorts.
     * @param sorts
     */
    onSelectedSorts(sorts: ISortAttributesInput[]): void;
    /**
     * Initializes the component for paginator usage.
     * @private
     */
    private initializeComponentForPaginatorUsage;
    /**
     * Resets the inbox component.
     */
    private resetComponent;
    static ɵfac: i0.ɵɵFactoryDeclaration<InboxComponent, never>;
    static ɵcmp: i0.ɵɵComponentDeclaration<InboxComponent, "talenra-inbox, talenra-workspace-inbox", never, { "dataItems": { "alias": "dataItems"; "required": false; }; "attributes": { "alias": "attributes"; "required": true; }; "presets": { "alias": "presets"; "required": false; }; "activePresetName": { "alias": "activePresetName"; "required": false; }; "detailViewTabs": { "alias": "detailViewTabs"; "required": false; "isSignal": true; }; "inboxConfigurationPanelTabs": { "alias": "inboxConfigurationPanelTabs"; "required": false; "isSignal": true; }; "loading": { "alias": "loading"; "required": false; }; "pairingAttributes": { "alias": "pairingAttributes"; "required": false; }; "noteBoxItems": { "alias": "noteBoxItems"; "required": false; }; "refreshing": { "alias": "refreshing"; "required": false; }; "selectDataItem": { "alias": "selectDataItem"; "required": false; }; "lockedDataItems": { "alias": "lockedDataItems"; "required": false; }; "usePagination": { "alias": "usePagination"; "required": false; }; "paginatorState": { "alias": "paginatorState"; "required": false; }; "query": { "alias": "query"; "required": false; "isSignal": true; }; "possibleRules": { "alias": "possibleRules"; "required": false; "isSignal": true; }; "possibleOptions": { "alias": "possibleOptions"; "required": false; "isSignal": true; }; }, { "query": "queryChange"; "clickedDataItemEmitter": "clickedDataItemEmitter"; "dataItemsInteractions": "dataItemsInteractions"; "presetAction": "presetAction"; "virtualScrollerPosition": "virtualScrollerPosition"; "selectedMainAttributesEmitter": "selectedMainAttributesEmitter"; "selectedDetailAttributesEmitter": "selectedDetailAttributesEmitter"; "selectedAllAttributesEmitter": "selectedAllAttributesEmitter"; "filterSortSearchEmitter": "filterSortSearchEmitter"; "refreshingChange": "refreshingChange"; "paginatorStateChange": "paginatorStateChange"; }, never, ["[further-actions-toolbar-menu]", "[custom-toolbar-space]", "[further-actions-data-item-menu]", "*", "[inbox-note-box]", "*", "[custom-data-items-list]"], true, never>;
    static ngAcceptInputType_usePagination: unknown;
}
