import { EventEmitter, OnDestroy } from '@angular/core';
import { BehaviorSubject } from 'rxjs';
import { FilterToolbarService } from '../../filter-toolbar/filter-toolbar.service';
import { InboxState } from '../state/inbox.state';
import { IDataItemId } from '../../shared/interfaces/data-item-id.interface';
import { DataItemsClass } from '../../shared/classes/dataItem.class';
import { IInteractedDataItems } from '../../shared/interfaces/interacted-data-items.interface';
import { InboxDetailViewService } from '../../inbox-layout/inbox-detail-view/inbox-detail-view.service';
import { DataItemsService } from '../../inbox-layout/data-items-list/data-items.service';
import { InboxToolbarService } from '../../inbox-toolbar/inbox-toolbar.service';
import { PresetsService } from '../../inbox-toolbar/presets-menu/presets.service';
import * as i0 from "@angular/core";
/**
 * Service to handle keyboard events.
 * Specific key are registered and propagated to the components.
 * Specific keys are subscribable.
 */
export declare class KeyboardService implements OnDestroy {
    /**
     * Class to interact with data-items-list-data.
     */
    dataItemsClass: DataItemsClass;
    /**
     * Data Items which are filtered by the search
     */
    searchedDataItems: any[];
    /**
     *  Value to what value is to be scrolled in the data-item-list
     */
    scrollToIndex: number;
    /**
     * Some icon buttons are disabled at the moment
     */
    disabledButtonNoDataItemFound: boolean;
    /**
     * The boolean if the shift key is pressed.
     */
    shiftKeyPressed: BehaviorSubject<boolean>;
    /**
     * The boolean if the meta key is pressed.
     */
    readonly metaKeyPressed: BehaviorSubject<boolean>;
    /**
     * The boolean if the control key is pressed.
     */
    readonly controlKeyPressed: BehaviorSubject<boolean>;
    /**
     * The boolean if the escape key is pressed.
     */
    readonly escapeKeyPressed: BehaviorSubject<boolean>;
    /**
     * The boolean if the enter key is pressed.
     */
    readonly enterKeyPressed: BehaviorSubject<boolean>;
    /**
     * The boolean if the v key is pressed.
     */
    readonly vKeyPressed: BehaviorSubject<boolean>;
    /**
     * Determines whether arrowLeft key is pressed.
     */
    readonly arrowLeftKeyPressed: BehaviorSubject<boolean>;
    /**
     * The boolean if the arrowRight key is pressed.
     */
    readonly arrowRightKeyPressed: BehaviorSubject<boolean>;
    /**
     * The boolean if the big detail view is shown.
     */
    bigDetailViewScreen: BehaviorSubject<boolean>;
    /**
     * The boolean if data item list is refreshing.
     */
    refreshing: boolean;
    /**
     * The icon button function to be called when a key is pressed.
     */
    iconBtnFunction?: (btn: string) => void;
    /**
     * The data ite, interactions function to be called when a key is pressed.
     * Passed on from the inbox component to emit the specific event.
     */
    dataItemsInteractions?: EventEmitter<IInteractedDataItems>;
    /**
     * The data item selected function to be called when a key is pressed.
     */
    dataItemSelectedFunction?: (dataItem: any) => void;
    /**
     * The clicked data item emitter to be called when a key is pressed.
     * Passed on from the inbox component to emit the clicked data Item.
     */
    clickedDataItemEmitter?: EventEmitter<any>;
    /**
     * The boolean if the data items are available.
     */
    dataItemsAvailable?: boolean;
    /**
     * The locked data items for the data item list.
     */
    lockedDataItems?: IDataItemId[];
    /**
     * The state of the inbox.
     */
    inboxState: InboxState;
    /**
     * The public service of the inbox detail viewe.
     */
    inboxDetailViewService: InboxDetailViewService;
    /**
     * The public service of the data items.
     */
    dataItemsService: DataItemsService;
    /**
     * The public service of the inbox toolbar.
     */
    inboxToolbarService: InboxToolbarService;
    /**
     * The public service of the filter toolbar.
     */
    filterToolbarService: FilterToolbarService;
    /**
     * The public service of the presets.
     */
    presetsService: PresetsService;
    /**
     * The timeout length for the keys.
     * Used to set the timeout for the keys.
     */
    private timeOutLength;
    /**
     * The timeout id for the shift key.
     * Used to clear the timeout for the shift key.
     */
    private timeoutShiftId?;
    /**
     * The timeout id for the meta key.
     * Used to clear the timeout for the meta key.
     */
    private timeoutMetaId?;
    /**
     * The timeout id for the control key.
     * Used to clear the timeout for the control key.
     */
    private timeoutControlId?;
    /**
     * The subscriptions of the service.
     * @internal
     */
    private subscriptions;
    /**
     * Constructor of the service.
     * @internal
     */
    constructor();
    /**
     * Unsubscribes all subscriptions.
     * @internal
     */
    ngOnDestroy(): void;
    /**
     * Registers key click and propagate to components.
     * @param {KeyboardEvent} event Clicked Key.
     */
    keyUpEvent(event: KeyboardEvent): void;
    /**
     * Registers key click and propagate to components.
     * @param {KeyboardEvent} event Clicked Key.
     */
    keyDownEvent(event: KeyboardEvent): void;
    /**
     * Get the next possible selected data item.
     * If returned -2 the next data item is not selectable.
     * @param index The index of the current selected data item.
     * @param direction The direction of the next data item (1 = down, -1 = up).
     */
    getNextDataItemIndex(index: number, direction: number): number;
    /**
     * Getter for the list of data items which are chosen in the data items list.
     * @param {any[]} dataItems The list of dataItems.
     * @param {string[]} dataItemsListId The list of data items ids.
     * @internal
     */
    getBulkDataItemsList(dataItems: any, dataItemsListId: string[]): any[];
    /**
     * Closes all mat-menus, attribute-settings and action menu.
     * @param notClose The menu that should not be closed.
     */
    closeAllMenus(notClose?: string): void;
    /**
     * Opens or closes the side panel and sets the correct tab.
     * @param tab The tab to open or close.
     */
    handleSidePanel(tab: string): void;
    static ɵfac: i0.ɵɵFactoryDeclaration<KeyboardService, never>;
    static ɵprov: i0.ɵɵInjectableDeclaration<KeyboardService>;
}
