import { EventEmitter } from '@angular/core';
import { BehaviorSubject, Subscription } from 'rxjs';
import { FormGroup } from '@angular/forms';
import { KeyboardService } from './keyboard.service';
import { IAttributeItem } from '../../shared/interfaces/attribute-item.interface';
import { IAttributeItemInput } from '../../shared/interfaces/attribute-item-input.interface';
import { IIconInput } from '../../shared/interfaces/icon-input.interface';
import { FilterToolbarService } from '../../filter-toolbar/filter-toolbar.service';
import { InboxState } from '../state/inbox.state';
import { IDataItemId } from '../../shared/interfaces/data-item-id.interface';
import { IInteractedDataItems } from '../../shared/interfaces/interacted-data-items.interface';
import { InboxDetailViewService } from '../../inbox-layout/inbox-detail-view/inbox-detail-view.service';
import { DataItemsService } from '../../inbox-layout/data-items-list/data-items.service';
import { IInboxTabBarItem } from '../../shared/interfaces/inbox-tab-bar-item.interface';
import { IFilterSortSearch } from '../../shared/interfaces/filter-search-sort.interface';
import { IInboxFilterSortSearch } from '../../shared/interfaces/inbox-filter-sort-search.interface';
import { FilterStateService } from '../../simple-filter-selection/state/filter.state';
import { IFilterAttribute } from '../../shared/interfaces/filter-attribute.interface';
import { ISortAttributesInput } from '../../shared/interfaces/sort-attributes-input.interface';
import * as i0 from "@angular/core";
export declare class MainFacadeSetterService {
    /**
     * The emitter for the clicked data item.
     */
    clickedDataItemEmitter: EventEmitter<any>;
    /**
     * EventEmitter to emit the filter, sort and search values to the consuming application.
     */
    filterSortSearchEmitter: EventEmitter<IFilterSortSearch>;
    /**
     * The form-group defines the search field, gets passed into the component.
     */
    searchField: FormGroup;
    /**
     * The maximum Attributes, which are to be shown in the data-items-list.
     * Further they are divided in the ui.
     * Marks the border for which values are saved to attributes and attributes-detail in attributes-settings.
     * Default value is 12, like chosen in the requirements.
     */
    maxMainAttributes: number;
    /**
     * The maximum Attributes, which are to be shown in the detail-view.
     * Default value is 100, like chosen in the requirements.
     */
    maxAttributesDetail: number;
    /**
     * The list of all attributes generated by the attributes input supplied by the consuming app or generated by the data
     * items if the attributes are not supplied by the consuming application.
     */
    allAttributes$: BehaviorSubject<IAttributeItem[]>;
    /**
     * The list of all attributes supplied by the consuming app.
     */
    allUntransformedAttributes$: BehaviorSubject<IAttributeItemInput[]>;
    /**
     * The number of main attributes chosen by the user.
     * Default value is 12, like chosen in the requirements. Will be overwritten by the consuming app through the view  or inbox configuration.
     */
    numberMainAttributesChosenByUser$: BehaviorSubject<number>;
    /**
     * The selection of icons that are to be used to filter and flag the data items.
     */
    iconSelection: IIconInput[];
    /**
     * The filter selection get from the presets.
     */
    filterSelection: IFilterAttribute[];
    /**
     * The sort selection get from the presets.
     */
    sortSelection: ISortAttributesInput[];
    /**
     * The position of the virtual scroller.
     */
    virtualScrollerPosition$: BehaviorSubject<number>;
    /**
     * Flag to check if the detail view is expanded or not and should be opened after data items refresh.
     */
    reOpenDetailViewAfterRefresh: boolean | undefined;
    /**
     * Filter, Sort and Search emitter buffer element.
     * Saves the previous state of the filter, sort and search.
     * Used to recognize changes in the filter, sort and search and not emit the same state again.
     */
    filterSortSearchEmitterBuffer: IFilterSortSearch;
    /**
     * The subscription for the inbox.
     * @internal
     */
    subscriptions: Subscription;
    /**
     * The subscriptions of the detail view.
     * @internal
     */
    detailViewSubscriptions: Subscription;
    /**
     * The service of the data items.
     */
    dataItemsService: DataItemsService;
    /**
     * The service of the keyboard.
     */
    keyboardService: KeyboardService;
    /**
     * The service of the filter toolbar.
     */
    filterToolbarService: FilterToolbarService;
    /**
     * The state of the inbox.
     */
    inboxState: InboxState;
    /**
     * The state of the inbox.
     */
    filterState: FilterStateService;
    /**
     * The service of the inbox detail view.
     */
    inboxDetailViewService: InboxDetailViewService;
    /**
     * Class to interact with data items.
     */
    private dataItemsClass;
    /**
     * The value if the side panel is to be shown after no results found.
     */
    private reopenInboxDetailView;
    /**
     * Data items which are filtered by the search.
     */
    private searchedDataItems;
    /**
     * Initial Attributes for the detail-view.
     * Used to initialize the attribute to the correct list (detail).
     */
    private dataItemsListAttributesDetail;
    /**
     * Initial Attributes for the data-items-list.
     * Used to initialize the attribute to the correct list (main).
     */
    private dataItemsListAttributesMain;
    /**
     * Set the filter, sort and search emitter.
     * @param filterSortSearchEmitter
     */
    setFilterSortSearchEmitter(filterSortSearchEmitter: EventEmitter<IFilterSortSearch>): void;
    /**
     * Sets the attribute list.
     * @param attributeList The attribute list.
     */
    setAllAttributes(attributeList: IAttributeItem[]): void;
    /**
     * Sets the untransformed attribute list.
     * @param dataItemAttributes The untransformed attribute list.
     */
    setAllUntransformedAttributes(dataItemAttributes: IAttributeItemInput[]): void;
    /**
     * Sets the number of main attributes chosen by the user.
     * @param numberMainAttributesChosenByUser The number of main attributes chosen by the user.
     */
    setNumberMainAttributesChosenByUser(numberMainAttributesChosenByUser: number): void;
    /**
     * Sets the icon selection.
     * @param iconAttribute The icon selection.
     */
    setIconSelection(iconAttribute: IIconInput[]): void;
    /**
     * Sets the virtual scroller position.
     * @param virtualScrollerPosition The virtual scroller position.
     */
    setVirtualScrollerPosition(virtualScrollerPosition: number): void;
    /**
     * Sets the detail view tabs after view init of the consuming app.
     * @param detailViewTabsChanges Changes of the detail view tabs.
     */
    resetDetailViewTabs(detailViewTabsChanges: IInboxTabBarItem[]): IInboxTabBarItem[];
    /**
     * Sets the picked attributes for the attributes-settings.
     * Used to initialize the attributeList, if attributes are defined by consuming app.
     */
    setPickedAttributes(): void;
    /**
     * Sets the selected dataItemListAttributes in the attributes-settings-service (SELECTED = CHECKED).
     * The attributes-settings-service is used to communicate with the attributes-settings (main and detail attributes).
     */
    setSelectedAttributeListInsideAttributesSettingsService(): void;
    /**
     * Determines the order of the picked data-item-list attributes.
     * @param mainAttributesData Main attributes.
     * @param detailsAttributesData Detail attributes.
     */
    determineOrderOfPickedAttributes(mainAttributesData: IAttributeItem[], detailsAttributesData: IAttributeItem[]): void;
    /**
     * All changes through the filter-toolbar are subscribed.
     * The displayed data-item-list adept to the filter changes.
     */
    setFilterAndSearchSubscriptions(clickedDataItemEmitter: any): void;
    /**
     * Initializes the data items list.
     * @param dataItems The data items.
     */
    initializeDataItemsList(dataItems: any[]): void;
    /**
     * Handler for the data items when no data items are found.
     * @internal
     */
    noDataItemsFound(): void;
    /**
     * Sets the necessary properties in the keyboard-service.
     * Allows the keyboard-service to access the properties of the inbox-component.
     */
    setKeyboardServiceConfiguration(iconBtnFunction: (btn: string) => void, dataItemsInteractions: EventEmitter<IInteractedDataItems>, dataItemsAvailable: boolean, dataItemSelectedFunction: (dataItem: any) => void, clickedDataItemEmitter: EventEmitter<any>, lockedDataItems: IDataItemId[]): void;
    /**
     * Sets the default value of expanded detailView, selectedDataItem and selectedItem of detailView.
     */
    setDefaultStateOfInboxLayout(dataItems: any, clickedDataItemEmitter: any): void;
    /**
     * Handler for the clicked data item.
     * @param dataItem The clicked data item.
     * @param clickedDataItemEmitter The clicked data item emitter.
     */
    clickedDataItemFunction(dataItem: any, clickedDataItemEmitter: any): void;
    /**
     * Function to handle the search field input.
     * @param search The search value.
     */
    onSearchFieldChange(search: string): void;
    /**
     * Emit the filter, sort and search values to the consuming application.
     * Sets buffer element to the current value.
     */
    publishFilterSortSearch(value: IFilterSortSearch): void;
    /**
     * CompareElem is used to compare two elements of the IFilterSortSearch or IInboxFilterSortSearch interface.
     * @param a First element to compare.
     * @param b Second element to compare.
     */
    compareFilterSortSearch(a: IFilterSortSearch | IInboxFilterSortSearch, b: IFilterSortSearch | IInboxFilterSortSearch): boolean;
    /**
     * Compares the filter and sort values between two values.
     * @param a First element to compare.
     * @param b Second element to compare.
     */
    compareFilterSort(a: IFilterSortSearch | IInboxFilterSortSearch, b: IFilterSortSearch | IInboxFilterSortSearch): boolean;
    /**
     * Initializes the filter and sort state from the preset.
     */
    initializeFilterSortStateFromPreset(): void;
    static ɵfac: i0.ɵɵFactoryDeclaration<MainFacadeSetterService, never>;
    static ɵprov: i0.ɵɵInjectableDeclaration<MainFacadeSetterService>;
}
