import { IIconInput } from './icon-input.interface';
import { ISelectionFilterValue } from './filter-attribute.interface';
import { TAttributeFilterModes, TDateFilterRestrictions } from './attribute-item.interface';
/**
 * AttributeItemInput is used to further define the attributes that are displayed in the inbox
 * The attributes of the items are enhanced by a label, a filterable property, selection if it's a displayed attribute and a quick icon filter property.
 *
 * @example
 * // Import
 * import { AttributeItemInput } from '@talenra/ngx-inbox';
 *
 * const attributes: AttributeItemInput[] = [
 *   {
 *     identifier: 'caseFlags',
 *     label: 'Hinweise',
 *     defaultAttribute: 'detail',
 *     iconFilter: {
 *       identifier: 'caseFlags',
 *       icon: 'error',
 *       activeIconColor: 'primary',
 *       iconTooltip: 'Hinweis',
 *       displayedString: (elem) => {
 *         return 'Beinhaltet die Rolle MA' + elem['caseFlags'].filter((s: string | string[]) => s.includes('MA')).length;
 *       },
 *       assignmentCondition: (elem) => {
 *         return elem['caseFlags'].filter((s: string | string[]) => s.includes('MA')).length != 0;
 *       },
 *     },
 *   },
 *   // attribute for complex data structure (see section `dataItems`)
 *   {
 *     identifier: 'workflowCase.pvRoles',
 *     label: 'Hinweise',
 *     filterable: 'multi-select',
 *     defaultAttribute: 'detail',
 *     singleMultiSelectOptions: ['Mitglied prüfen', 'Lohndeklaration erfassen', 'Partner prüfen'],
 *   },
 *   {
 *     identifier: 'workflowCase.initialElements.partnerFlag',
 *     label: 'Hinweise',
 *     filterable: 'multi-select',
 *     allowEmptyDataItemFilter: false,
 *   },
 * ];
 */
export interface IAttributeItemInput {
    /**
     * The identifier of the attribute (has to correspond with the key of the attribute).
     */
    identifier: string;
    /**
     * The label should be the translation of the identifier (is the text displayed in the inbox).
     */
    label: string;
    /**
     * The filterMode attribute defines the type of filter that is used for the attribute.
     * 'multi-select' | 'single-select' | 'date-range' | 'char-range' | 'number-range' | 'text-field'.
     * 'multi-select' is used for attributes with a string value and enables multiple options.
     * 'single-select' is used for attributes with a string value allows only one option.
     * 'date-range' is used for attributes with a date value (type has to be Date).
     * 'char-range' is used for attributes with a string value.
     * 'number-range' is used for attributes with a number value.
     * 'text-field' is used for attributes with a string value and enables a text field.
     */
    filterMode?: TAttributeFilterModes;
    /**
     * Restrictions that apply to the filterMode = `date-range`. The chosen option is applied to both input fields.
     */
    dateFilterRestriction?: TDateFilterRestrictions;
    /**
     * The sortable attribute defines if the attribute is sortable.
     */
    sortable?: boolean;
    /**
     * Defines if the attribute is the main attribute or the detail attribute.
     * 'main' | 'detail'
     * 'main' if chosen the attributes are displayed in the list items (first 12 "main" attributes are displayed in the lis further are moved to detail view).
     * 'detail' if chosen the attributes are displayed in the detail view.
     * if no defaultAttribute is defined, the attribute is not displayed in the inbox.
     */
    defaultAttribute?: 'main' | 'detail';
    /**
     * Defines if the attribute should be filtered with an icon (quick filter).
     */
    iconFilter?: IIconInput;
    /**
     * Defines the options for the single and multi select filter for the specific attribute. Overwrites the default options filled by the `dataItems` input.
     */
    filterSelectionOptions?: ISelectionFilterValue[];
    /**
     * Defines if the options for the filter should contain the not available option '–'.
     * If set to true, the options will contain the '–' option (default).
     * If set to false, the options will not contain the '–' option.
     * If not set, the options will contain the '–' option.
     * The '–' option is used to filter for items that have no value for the specific attribute.
     */
    allowEmptyDataItemFilter?: boolean;
}
