/**
 * Const for the operator modes of the filter attributes.
 */
export declare const FilterAttributeOperators: {
    readonly Equal: "equal";
    readonly NotEqual: "notEqual";
};
/**
 * Type of bottom bar actions.
 */
export type TFilterAttributeOperators = (typeof FilterAttributeOperators)[keyof typeof FilterAttributeOperators];
/**
 * IFilterAttribute is used to filter the data based on the selected attributes.
 * **Important Information:**
 *
 * 1. **The identifier must already be used in selectedAttributes (SelectedAttributesInput[]).**
 *
 * ```typescript
 * import { IFilterAttribute } from '@talenra/ngx-inbox';
 *
 * const filterAttributeMultiSelect: IFilterAttribute = { identifier: 'animal.mammal', value: [{ key: 'landAnimalMonkey', label: 'Monkey' }, { key: 'waterAnimalWhale', label: 'Whale' }] };
 * const filterAttributeSingleSelect: IFilterAttribute = { identifier: 'animal.mammal', value: { key: 'waterAnimalWhale', label: 'Whale' } };
 * const filterAttributeCharRange: IFilterAttribute = { identifier: 'animal.mammal', value: { start: 'AR', end: 'JAB' } };
 * const filterAttributeNumberRange: IFilterAttribute = { identifier: 'animal.weight.kg', value: { start: 50, end: 1600 } };
 * const filterAttributeDateRange: IFilterAttribute = { identifier: 'animal.birthDate', value: { start: new Date('01.14.2023'), end: new Date('01.14.2024') } };
 * ```
 */
export interface IFilterAttribute {
    /**
     * As the filter types are already defined in {@link IAttributeItemInput}, only the identifier and values for the filter are necessary to set.
     */
    identifier: string;
    /**
     * Operator for the filter.
     */
    operator?: TFilterAttributeOperators;
    /**
     * The values are defined for the filter modes ({@link IAttributeItemInput}) as:
     *
     * - single-select: SelectionFilterValue
     * - multi-select: SelectionFilterValue[]
     * - char-range: CharRangeFilterValue
     * - number-range: NumberRangeFilterValue
     * - date-range: DateRangeFilterValue
     * - text-field: string
     */
    value?: ISelectionFilterValue | ISelectionFilterValue[] | ICharRangeFilterValue | INumberRangeFilterValue | IDateRangeFilterValue | string;
}
/**
 * FilterValue is used to correlate a filter value with a key and label.
 * Enables the to display a label and identify the value by a key.
 *
 * ```typescript
 * import { ISelectionFilterValue } from '@talenra/ngx-inbox';
 * const filterValue: ISelectionFilterValue = { key: '8001', label: 'John Doe' };
 * ```
 */
export interface ISelectionFilterValue {
    /**
     * Key that identifies the value.
     */
    key: string;
    /**
     * Label that is displayed for the value.
     */
    label: string;
}
/**
 * Is used to define a character range filter value.
 *
 * ```typescript
 * import { ICharRangeFilterValue } from '@talenra/ngx-inbox';
 * const charRangeFilterValue: ICharRangeFilterValue = { start: 'AR', end: 'JAB' };
 * ```
 */
export interface ICharRangeFilterValue {
    /**
     * Start value of the character range.
     */
    start?: string;
    /**
     * End value of the character range.
     */
    end?: string;
}
/**
 * Is used to define a number range filter value.
 *
 * ```typescript
 * import { INumberRangeFilterValue } from '@talenra/ngx-inbox';
 * const numberRangeFilterValue: INumberRangeFilterValue = { start: 1, end: 6 };
 * ```
 */
export interface INumberRangeFilterValue {
    /**
     * Start value of the number range.
     */
    start?: number;
    /**
     * End value of the number range.
     */
    end?: number;
}
/**
 * Is used to define a date range filter value.
 *
 * ```typescript
 * import { IDateRangeFilterValue } from '@talenra/ngx-inbox';
 * const dateRangeFilterValue: IDateRangeFilterValue = { start: new Date('01.14.2023'), end: new Date('01.14.2024') };
 * ```
 */
export interface IDateRangeFilterValue {
    /**
     * Start value of the date range.
     */
    start?: Date | null;
    /**
     * End value of the date range.
     */
    end?: Date | null;
}
