import { IQueryBuilderQuery } from '@talenra/ngx-base/query-builder';
import { ISortAttributesInput } from './sort-attributes-input.interface';
import { IIconFiltersInput } from './icon-filters-input.interface';
/**
 * IInboxFilterSortSearch is used to define what kind of filters, sort and searched text are used in the inbox.
 *
 * ```typescript
 * import { IInboxFilterSortSearch } from '@talenra/ngx-inbox';
 *
 * filterSortSearch: IInboxFilterSortSearch = {
 *   searchText: 'searched text',
 *   sortAttributes: [{identifier: 'caseId', sort: 'asc'}],
 *   filterAttributes: {
 *     condition: QueryBuilderCondition.And,
 *     identifier: '55cd7293-532c-4182-9f20-f45291a4cf52',
 *     hierarchyLevel: 1,
 *     rules: [
 *       {
 *         identifier: '07464769-386a-4b81-a6a7-378b36e7fb99',
 *         key: 'case.caseTypeName',
 *         label: 'Falltyp',
 *         type: 'option',
 *         operator: 'contains',
 *         value: 'Zahlungsauftrag erteilen',
 *       },
 *       {
 *         identifier: '07464769-386a-4b81-a6a7-378b36e7fb69',
 *         key: 'case.leadingKpvPartID',
 *         label: 'leadingKpvPartID',
 *         type: 'number',
 *         operator: 'greater',
 *         value: 12312321,
 *       },
 *       {
 *         identifier: '07464769-386a-4b81-a6a7-378b36e7fb22',
 *         key: 'case.caseID',
 *         label: 'Fall-ID',
 *         type: 'string',
 *         operator: 'startsWith',
 *         value: 'ZH-20230510-0014648',
 *       },
 *       {
 *         condition: QueryBuilderCondition.Or,
 *         identifier: '07464769-386a-4b81-a6a7-378b36e7fb32',
 *         hierarchyLevel: 2,
 *         rules: [
 *           {
 *             identifier: '07464769-386a-4b81-a6a7-378b36e7fb48',
 *             key: 'case.caseStartDate',
 *             label: 'Falleröffnung',
 *             type: 'date',
 *             operator: 'before',
 *             value: new Date('1990-01-01'),
 *           },
 *           {
 *             identifier: '07464769-386a-4b81-a6a7-378b36e7fb52',
 *             key: 'isReallocated',
 *             label: 'Neu zugeteilt',
 *             type: 'boolean',
 *             value: true,
 *           },
 *         ],
 *       },
 *     ],
 *   },
 *   iconAttributes: [{ icon: "error", identifier: "icon_error_insuree.partnerFlags" }],
 * };
 * ```

 */
export interface IInboxFilterSortSearch {
    /**
     * Searched text in the search bar.
     **/
    searchText: string;
    /**
     * SortAttributes is used to define which attributes are used to sort the items in the inbox.
     */
    sortAttributes: ISortAttributesInput[];
    /**
     * FilterAttributes is used to define which attributes are used to filter the items in the inbox.
     */
    filterAttributes: IQueryBuilderQuery;
    /**
     * IconAttributes is used to define which icon filters are active in the inbox.
     */
    iconAttributes: IIconFiltersInput[];
}
