import { IPreset } from './preset.interface';
/**
 * Attribute filter modes
 */
export declare const PresetOperations: {
    readonly Create: "create";
    readonly Update: "update";
    readonly Rename: "rename";
    readonly UpdateRename: "update & rename";
    readonly AttributeUpdate: "attribute-update";
    readonly Delete: "delete";
    readonly VisibilityOff: "visibility-off";
    readonly VisibilityOn: "visibility-on";
    readonly DragDrop: "dragDrop";
    readonly PositionUp: "position-up";
    readonly PositionDown: "position-down";
    readonly None: "none";
};
/**
 * Type of attribute filter modes
 */
export type TPresetOperations = (typeof PresetOperations)[keyof typeof PresetOperations];
/**
 * IPresetAction used to define the action to be performed on the presets in the inbox.
 *
 * @example
 * import { IPresetAction } from '@talenra/ngx-inbox';
 *
 * presetAction: IPresetAction = {
 *  presets: [
 *  {
 *   identifier: '121bd936-ce20-4ea9-9dc1-6cdaf61f9c3d',
 *   name: 'Meine Inbox',
 *   changeable: false,
 *   selectedAttributes:
 *     [
 *       { identifier: 'case.caseTypeName', defaultAttribute: 'main' },
 *       { identifier: 'case.caseID', defaultAttribute: 'detail' },
 *     ],
 *   children:
 *     [
 *       {
 *         name: 'View 1',
 *         numberMainAttributesChosenByUser: 4,
 *         selectedAttributes: [
 *           { identifier: 'case.caseTypeName', defaultAttribute: 'main' },
 *           { identifier: 'case.caseID', defaultAttribute: 'main' },
 *           { identifier: 'processStep', defaultAttribute: 'detail' },
 *           { identifier: 'insuree.lastNameOrgName', defaultAttribute: 'detail' },
 *           { identifier: 'case.caseStartDate', defaultAttribute: 'detail' },
 *           { identifier: 'member.lastNameOrgName', defaultAttribute: 'detail' },
 *           { identifier: 'insuree.socialSecurityNumber', defaultAttribute: 'detail' },
 *           { identifier: 'case.casePriority', defaultAttribute: 'main' },
 *         ],
 *         sortAttributes: [
 *           { identifier: 'case.caseTypeName', sort: 'asc' },
 *           { identifier: 'insuree.socialSecurityNumber', sort: 'desc' },
 *         ],
 *         filterAttributes: [
 *           {
 *             identifier: 'case.caseTypeName',
 *             value: ['Direkt eingegangene Beschwerde'],
 *           },
 *           {
 *             identifier: 'case.caseStartDate',
 *             value: [new Date('01.15.2020'), new Date('12.30.2023')],
 *           },
 *           { identifier: 'case.casePriority', value: [1, 2] },
 *         ],
 *         iconAttributes: [],
 *       },
 *       {
 *         name: 'View 2',
 *         numberMainAttributesChosenByUser: 4,
 *         selectedAttributes: [
 *           { identifier: 'case.caseTypeName', defaultAttribute: 'main' },
 *           { identifier: 'case.caseID', defaultAttribute: 'main' },
 *           { identifier: 'processStep', defaultAttribute: 'detail' },
 *           { identifier: 'insuree.lastNameOrgName', defaultAttribute: 'detail' },
 *           { identifier: 'case.caseStartDate', defaultAttribute: 'detail' },
 *           { identifier: 'member.lastNameOrgName', defaultAttribute: 'detail' },
 *         ],
 *         sortAttributes: [{ identifier: 'case.caseTypeName', sort: 'asc' }],
 *         filterAttributes: [
 *           {
 *             identifier: 'case.caseTypeName',
 *             value: ['Direkt eingegangene Beschwerde'],
 *           },
 *         ],
 *         iconAttributes: [],
 *       },
 *     ],
 *  }
 *  ],
 *  operation: 'create',
 *  groupName: 'Meine Inbox',
 *  presetName: 'View 2',
 *  };
 */
export interface IPresetAction {
    /**
     * The updated presets.
     */
    presets: IPreset[];
    /**
     * The operation to be performed on the presets.
     */
    operation: TPresetOperations;
    /**
     * The group name of the preset which has been updated or created.
     */
    groupName: string;
    /**
     * The preset name of the preset which has been updated or created.
     */
    presetName?: string;
    /**
     * The new preset name which has been updated or created.
     */
    newPresetName?: string;
}
