import { IIconFiltersInput } from './icon-filters-input.interface';
import { ISelectedAttributesInput } from './selected-attributes-input.interface';
import { ISortAttributesInput } from './sort-attributes-input.interface';
import { IFilterAttributesInput } from './filter-attributes-input.interface';
/**
 * IPreset is used to define a specific preset for the inbox.
 *
 * @example
 * import { IPreset } from '@talenra/ngx-inbox';
 *
 * const presets: IPreset = {
 *   identifier: '121bd936-ce20-4ea9-9dc1-6cdaf61f9c3d',
 *   name: 'Meine Inbox',
 *   changeable: false,
 *   selectedAttributes:
 *     [
 *       { identifier: 'case.caseTypeName', defaultAttribute: 'main' },
 *       { identifier: 'case.caseID', defaultAttribute: 'detail' },
 *     ],
 *   children:
 *     [
 *       {
 *         name: 'View 1',
 *         numberMainAttributesChosenByUser: 4,
 *         selectedAttributes: [
 *           { identifier: 'case.caseTypeName', defaultAttribute: 'main' },
 *           { identifier: 'case.caseID', defaultAttribute: 'main' },
 *           { identifier: 'processStep', defaultAttribute: 'detail' },
 *           { identifier: 'insuree.lastNameOrgName', defaultAttribute: 'detail' },
 *           { identifier: 'case.caseStartDate', defaultAttribute: 'detail' },
 *           { identifier: 'member.lastNameOrgName', defaultAttribute: 'detail' },
 *           { identifier: 'insuree.socialSecurityNumber', defaultAttribute: 'detail' },
 *           { identifier: 'case.casePriority', defaultAttribute: 'main' },
 *         ],
 *         sortAttributes: [
 *           { identifier: 'case.caseTypeName', sort: 'asc' },
 *           { identifier: 'insuree.socialSecurityNumber', sort: 'desc' },
 *         ],
 *         filterAttributes: [
 *           {
 *             identifier: 'case.caseTypeName',
 *             value: [{ key: 'directWarning', label: 'Direkt Eingegangene Beschwerde' }, { key: 'directError', label: 'Direkt Fehler' }, ],
 *           },
 *           {
 *             identifier: 'case.caseStartDate',
 *             value: { start: new Date('01.14.2023'), end: new Date('01.14.2024') },
 *           },
 *           { identifier: 'case.casePriority', value: { start: 1, end: 2 } },
 *         ],
 *         iconAttributes: [],
 *       },
 *       {
 *         name: 'View 2',
 *         numberMainAttributesChosenByUser: 4,
 *         selectedAttributes: [
 *           { identifier: 'case.caseTypeName', defaultAttribute: 'main' },
 *           { identifier: 'case.caseID', defaultAttribute: 'main' },
 *           { identifier: 'processStep', defaultAttribute: 'detail' },
 *           { identifier: 'insuree.lastNameOrgName', defaultAttribute: 'detail' },
 *           { identifier: 'case.caseStartDate', defaultAttribute: 'detail' },
 *           { identifier: 'member.lastNameOrgName', defaultAttribute: 'detail' },
 *         ],
 *         sortAttributes: [{ identifier: 'case.caseTypeName', sort: 'asc' }],
 *         filterAttributes: [
 *           {
 *             identifier: 'case.caseTypeName',
 *             value: ['Direkt eingegangene Beschwerde'],
 *           },
 *         ],
 *         iconAttributes: [],
 *       },
 *     ],
 * };
 */
export interface IPreset {
    /**
     * Optional string to identify the item.
     * Used to identify the preset in the sidenav.
     */
    identifier?: string;
    /**
     * Name is used to define the name of the preset.
     **/
    name: string;
    /**
     * Visible attribute is used to define if the preset is visible in the sidenav or not.
     */
    visible?: boolean;
    /**
     * Changeable is used to define if the preset is changeable in the inbox or not.
     * Disable the option for user to overwrite the preset.
     */
    changeable?: boolean;
    /**
     * The number of chosen main attributes that are to be displayed in the attributes settings and data items list.
     */
    numberMainAttributesChosenByUser?: number;
    /**
     * The selectedAttributes is used to define which attributes are selected and displayed in the main or detail section.
     * If an attribute is not chosen, it will be displayed as unselected.
     */
    selectedAttributes: ISelectedAttributesInput[];
    /**
     * SortAttributes is used to define which attributes are used to sort the items in the inbox.
     */
    sortAttributes?: ISortAttributesInput[];
    /**
     * FilterAttributes is used to define which attributes are used to filter the items in the inbox.
     * Make sure to use only attributes which are already used in selectedAttributes (SelectedAttributesInput[])
     */
    filterAttributes?: IFilterAttributesInput[];
    /**
     * IconAttributes is used to define which icon filters are active in the inbox.
     */
    iconAttributes?: IIconFiltersInput[];
    /**
     * Children are used to define if the preset has child presets.
     */
    children?: IPreset[];
}
